10-K 1 d10k.txt FORM 10-K ================================================================================ UNITED STATES SECURITIES AND EXCHANGE COMMISSION WASHINGTON, D.C. 20549 ______________________________ FORM 10-K [X] ANNUAL REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934 For The Fiscal Year Ended June 30, 2001 [_] TRANSITION REPORT PURSUANT TO SECTION 13 OR 15(d) OF THE SECURITIES EXCHANGE ACT OF 1934 For the Transition Period from _____ to ____ ______________________________ Commission File Number 0-14278 MICROSOFT CORPORATION Washington 91-1144442 (State of incorporation) (I.R.S. ID) One Microsoft Way, Redmond, Washington 98052-6399 (425) 882-8080 Securities registered pursuant to Section 12(b) of the Act: None Securities registered pursuant to Section 12(g) of the Act: Common Stock Indicate by check mark whether the registrant (1) has filed all reports required to be filed by Section 13 or 15(d) of the Securities Exchange Act of 1934 during the preceding 12 months (or for such shorter period that the registrant was required to file such reports), and (2) has been subject to such filing requirements for the past 90 days. Yes [X] No [_] Indicate by check mark if disclosure of delinquent filers pursuant to Item 405 of Regulation S-K is not contained herein, and will not be contained, to the best of registrant's knowledge, in definitive proxy or information statements incorporated by reference in Part III of this Form 10-K or any amendment to this Form 10-K. [_] The aggregate market value of common stock held by non-affiliates of the registrant as of September 10, 2001 was $258,033,100,664. The number of shares outstanding of the registrant's common stock as of September 10, 2001 was 5,401,944,951. DOCUMENTS INCORPORATED BY REFERENCE Portions of the definitive Proxy Statement dated September 10, 2001 to be delivered to shareholders in connection with the Annual Meeting of Shareholders to be held November 7, 2001 are incorporated by reference into Part III. ================================================================================ MICROSOFT CORPORATION FORM 10-K For The Fiscal Year Ended June 30, 2001 INDEX

Part I Item 1. Business................................................................................. 1 Item 2. Properties............................................................................... 12 Item 3. Legal Proceedings........................................................................ 12 Item 4. Submission of Matters to a Vote of Security Holders...................................... 13 Executive Officers of the Registrant..................................................... 13 Part II Item 5. Market for Registrant's Common Stock and Related Stockholder Matters..................... 16 Item 6. Selected Financial Data.................................................................. 17 Item 7. Management's Discussion and Analysis of Results of Operations and Financial Condition.... 18 Item 7a. Quantitative and Qualitative Disclosures about Market Risk............................... 25 Item 8. Financial Statements and Supplementary Data.............................................. 27 Item 9. Changes in and Disagreements with Accountants on Accounting and Financial Disclosures.... 47 Part III Item 10. Directors of the Registrant.............................................................. 47 Item 11. Executive Compensation................................................................... 47 Item 12. Security Ownership of Certain Beneficial Owners and Management........................... 47 Item 13. Certain Relationships and Related Transactions........................................... 47 Part IV Item 14. Exhibits, Financial Statement Schedules, and Reports on Form 8-K......................... 48 Signatures............................................................................... 49

PART I Item 1. Business General -------------------------------------------------------------------------------- Microsoft Corporation (the "Company" or "Microsoft") was founded as a partnership in 1975 and incorporated in 1981. Microsoft develops, manufactures, licenses, and supports a wide range of software products for a multitude of computing devices. Microsoft(R) software includes scalable operating systems for servers, personal computers (PCs), and intelligent devices; server applications for client/server environments; knowledge worker productivity applications; and software development tools. The Company's online efforts include the MSN(R) network of Internet products and services and alliances with companies involved with broadband access and various forms of digital interactivity. Microsoft also licenses consumer software programs; sells hardware devices; provides consulting services; trains and certifies system integrators and developers; and researches and develops advanced technologies for future software products. Microsoft's business strategy emphasizes the development of a broad line of software products for information technology (IT) professionals, knowledge workers, developers, and consumers, marketed through multiple channels of distribution. The Company is structured around the following core groups: the Business Groups; the Worldwide Sales, Marketing, and Services Group; Microsoft Research; and the Operations Group. The Company's product segments, which are based on the Business Groups, are Desktop and Enterprise Software and Services, Consumer Software, Services, and Devices, Consumer Commerce Investments, and Other. The Desktop and Enterprise Software and Services segment includes the Platforms Group and the Productivity and Business Services Group. The Platforms Group has responsibility for continuing to evolve the Windows platform. In addition, the division includes the .NET Enterprise Server Group, the Developer Tools Division, and the Windows Digital Media Division. The Productivity and Business Services Group drives Microsoft's broad vision for productivity and business process applications and services. This group includes the Office Division, the Emerging Technologies Group, the Business Tools Division, and the Business Applications Group, which includes bCentral(TM) and Microsoft Great Plains(R). The Consumer Software, Services, and Devices segment contains the MSN Business Group; the Personal Services Business Group; and the Home and Retail Division. MSN Business Group runs the network programming, business development, and worldwide sales and marketing for MSN and Microsoft's other services efforts, including MSN eShop, the MSNBC venture, Slate(R), and MSNTV. The Personal Services Group (PSG) focuses on making it easier for consumers and businesses to connect online and to deliver software as a service on a variety of devices. PSG encompasses Microsoft's Personal .NET initiative, the Services Platform Division, the Mobility Group, the MSN Internet Access, Consumer Devices Group, and the User Interface Platform Division. The Home and Retail Division develops and markets learning and entertainment software and the future Xbox game console. The Consumer Commerce Investment segment includes Expedia, Inc., the HomeAdvisor(TM) online real estate service, and the MSN CarPoint(R) online automotive service. For financial reporting, revenue from Microsoft Press(R) and Hardware is included in the Other segment. The Worldwide Sales, Marketing, and Services Group integrates the activities of Microsoft's sales and service partners with the needs of Microsoft customers around the world. In addition, the group includes Microsoft Product Support Services, the Network Solutions Group, the Enterprise Partner Group, the Central Marketing Organization, and all three of Microsoft's major business-sales regions worldwide. Microsoft Research works on devising innovative solutions to computer science problems, such as making computers easier to use, designing software for the next generation of hardware, improving the software design process, and investigating the mathematical underpinnings of computer science. 1 The Operations Group is responsible for managing business operations and overall business planning. This includes corporate functions such as finance, administration, human resources, and information technology. Products Microsoft has four product segments: Desktop and Enterprise Software and Services; Consumer Software, Services, and Devices; Consumer Commerce Investments; and Other. See Notes to Financial Statements for financial information regarding segment reporting. Desktop and Enterprise Software and Services -------------------------------------------------------------------------------- Desktop and Enterprise Software and Services includes Desktop Applications; Desktop Platforms; and Enterprise Software and Services. For segment reporting purposes, Desktop Applications includes revenue from Microsoft Office, Microsoft Project, Microsoft Visio(R), Microsoft Great Plains, bCentral; and client access licenses for Windows NT(R) Server and Windows 2000 Server, Exchange, and BackOffice(R). Desktop Platforms includes revenue from Windows 2000 Professional, Windows NT Workstation, Windows Millennium Edition, Windows 98, and other desktop operating systems. Enterprise Software and Services includes Enterprise Platforms, Server Applications, Developer Tools and Services, and Enterprise Services. Desktop Applications -------------------- Microsoft Office. Microsoft Office is a suite of software programs featuring seamless integration of the most commonly used desktop applications. Microsoft Office is based upon a document-centric concept, with common commands and extensive use of cross-application capabilities. Microsoft Office is available in several versions, with certain combinations of products, and available for the Windows and Macintosh operating systems. Microsoft Office XP helps users complete common business tasks, including word processing, electronic mail (e- mail), presentations, and data management, with features like smart tags, task panes, integrated e-mail, document recovery, and send for review. Products offered in the various versions include the word processor Microsoft Word, Microsoft Excel spreadsheet, Microsoft Outlook(R) personal information management and communication client, Microsoft PowerPoint(R) presentation graphics program, Microsoft Access database management application, and others. Microsoft Word is a word-processing program designed to create documents such as reports, letters, business plans, and more. Microsoft Excel creates data-rich spreadsheets for universal viewing on the Internet and for collaboration, allows users to analyze data with charts, and incorporates Microsoft PivotTable(R) views and graphs. Microsoft Outlook personal information management and communication client provides a single, integrated solution for organizing and managing digital communication tools such as e-mail and instant messaging, along with day-to-day information, including calendars, contacts, task lists, and notes. Microsoft PowerPoint presentation graphics program is a complete set of tools for creating professional presentations. Microsoft Access database management application allows for easy access and retrieval of information and includes pre-packaged solutions to create databases quickly. Microsoft FrontPage(R) is a Web site creation and management tool for Web sites on the Internet or intranets. Microsoft Publisher business desktop publishing is a program for creating professional-looking marketing and business materials. Other Desktop Application Products. The Company also offers other stand-alone desktop application products. Microsoft Project is a project management program for scheduling, organizing, and analyzing tasks, deadlines, and resources. Microsoft Visio is a diagramming program that helps people visualize and communicate ideas, information, and systems. Most of the applications included in the various software program suites are also licensed separately. Microsoft Great Plains. Microsoft Great Plains offers a range of integrated business and accounting products, including Dynamics, Solomon, and eEnterprise, which deliver broad and deep functionality. Dynamics provides Internet-ready accounting and business management capabilities for small- to mid-sized companies. Solomon offers a full range of e-business and accounting applications for small- to mid-sized companies. eEnterprise supports mid-sized to larger companies by providing a collaborative environment for information management and sharing. 2 bCentral. Microsoft's small businesses portal, bCentral, allows companies to leverage the Internet to drive their business forward. Microsoft bCentral Site Manager is a Web site management and hosting service which empowers small businesses to easily create and manage their own Web sites, while allowing for higher-end editing in Microsoft FrontPage. Microsoft bCentral LinkExchange(TM) provides services to small businesses and Web site owners to increase their online traffic and sales with free advertising banner ads on their site in exchange for placing ads on other network sites. Client Access Licenses. A client access license gives a client computer the legal right to access a computer running a Microsoft server product and the services supported by the server. Desktop Platforms ----------------- Windows XP. Windows XP is the next major version of the Windows operating system and is scheduled for widespread availability in October 2001. Windows XP extends the personal computing experience by uniting PCs, devices, and services, and brings the solid foundation of Windows 2000 to home PC users, enhancing reliability, security, and performance. Windows XP Home Edition is designed for individuals or families at home and includes experiences for digital media, home networking, and communications. Windows XP Professional is for businesses of all sizes and for people who demand the most out of their computing experience. Windows XP Professional adds remote access, security, performance, manageability, and multilingual features to help users improve productivity and connectivity. Windows 2000 Professional. The successor to Windows NT Workstation, Windows 2000 Professional operating system combines features to create a mainstream operating system for desktop and notebook computing in all organizations. Windows 2000 Professional contains the enhanced business features of Windows 98 such as Plug and Play, easy-to-use user interface, and power management and integrates the strengths of Windows NT Workstation including standards-based security, manageability, and reliability. Windows NT Workstation. A fully integrated, multitasking 32-bit PC operating system, Windows NT Workstation provides security, robustness, and portability. Windows NT Workstation combines the Windows 98 operating system interface and usability features with the reliability and security of Windows NT for the business environment. Windows Millennium Edition. Windows Millennium Edition (Me) operating system is designed specifically for home users to manage digital photos and music, work with video, create a home network, and communicate with other consumers. Windows 98. The successor to Windows 95, Windows 98 is a personal computer operating system that provides a Web-oriented user interface and better system performance along with easier system diagnostics and maintenance. Windows 98 supports graphics, sound, and multimedia technologies and provides the ability to easily add and remove peripheral devices and support for Universal Serial Bus (USB). Enterprise Software and Services -------------------------------- Windows 2000 Server, Advanced Server, and Datacenter Server. Windows 2000 Server family builds on the Windows NT technology, integrating standards-based directory, Web, application, communications, file and print services with high reliability, efficient management, and support for networking hardware to provide the foundation for integrating with the Internet. Windows 2000 Server is a multipurpose network operating system for businesses of all sizes. Windows 2000 Advanced Server operating system is ideal for e-commerce and line-of- business applications and provides enhanced performance and scalability through symmetric multiprocessing (SMP) and extended memory support. Windows Datacenter Server operating system is built for large-scale line-of-business and enterprise backend usage and supports server consolidation and enhanced scalability. Windows NT Server. Windows NT Server is an operating system foundation for both server applications and file and print sharing, with network management features, administration tools, security, and high availability. Windows NT Server provides a scalable platform for business critical applications and databases, connectivity, system management, and e-mail servers. The operating system integrates Web services such as Microsoft Internet Information Server, a service used to manage intranet and Internet functionality, and Microsoft FrontPage Web site creation and management tool. Windows NT Server, 3 Terminal Server Edition, an extension to the Windows NT Server, offers the application support of the Windows operating system platform with the centrally managed environment of the mainframe with terminal. Windows NT Server Enterprise Edition provides the means for building and deploying large-scale distributed applications for large and mission-critical servers featuring comprehensive clustering for scalability and availability. Microsoft .NET Enterprise Servers. Microsoft .NET Enterprise Servers include Microsoft SQL Server(TM), Exchange Server, Application Center, BizTalk(TM) Server, Commerce Server, Content Management Server, Host Integration Server, Internet Security and Acceleration Server, Mobile Information Server, and SharePoint(TM) Portal Server. SQL Server is a fully Web-enabled database and data analysis product, providing core support for Extensible Markup Language (XML) and the ability to query across the Internet and beyond the firewall. Exchange Server is a messaging and collaboration server which provides e-mail, group scheduling, task management, and document routing capabilities. Application Center is Microsoft's deployment and management tool for high- availability Web applications built on the Microsoft Windows 2000 operating system. BizTalk Server enables companies to rapidly build and deploy integrated business processes within their organizations and with partners. Commerce Server provides a comprehensive set of features for building scalable, user- centric, business-to-consumer, and business-to-business e-commerce sites. Content Management Server is the enterprise Web content management system that enables companies to quickly and efficiently build, deploy, and maintain highly dynamic Internet, intranet, and extranet Web sites. Host Integration Server extends Microsoft Windows to other systems by providing application, data, and network integration. Internet Security and Acceleration Server provides secure, fast, and manageable Internet connectivity. It integrates an extensible, multilayer enterprise firewall and a scalable high-performance Web cache. Mobile Information Server mobile-enables the enterprise, extending the reach of Microsoft .NET Enterprise applications, enterprise data, and intranet content to the mobile user. SharePoint Portal Server extends the capabilities of Microsoft Windows and Microsoft Office by offering knowledge workers a powerful new way to easily organize, find, and share information. It combines the ability to easily create corporate Web portals with document management, content searching, and team collaboration features. Other Servers. Designed for the branch office, department, and medium-sized business, BackOffice Server provides a wide range of infrastructure and application services including directory, networking, Web application, database, messaging and collaboration, Internet proxy and firewall, host integration, and Windows desktop management. Proxy Server is an extensible firewall and Web cache server that provides Internet security while improving network response time and efficiency. Site Server is the powerful intranet server, optimized for Microsoft Windows NT Server with Internet Information Server, for publishing and finding information easier and faster. Site Server Commerce is a comprehensive Internet commerce server that organizations can use to build and monitor dynamic and cost-effective business sites that take full advantage of the Web. Small Business Server is the flexible network solution designed to help small businesses with up to 50 computers. SNA Server provides connectivity to host data and applications. Systems Management Server helps centrally manage the distributed environment with integrated features, including hardware inventory, software inventory and metering, software distribution and installation, and remote troubleshooting tools. Developer Tools and Services. Software development tools and computer languages allow software developers to write programs in a particular computer language and translate programs into a binary machine-readable set of commands that activate and instruct various hardware devices. The Company develops and markets a number of software development environments and language compilers. Microsoft Visual C++(R) is the Company's development system for Windows-based application development. The Microsoft Visual Basic(R) development system provides easy access to a wide variety of data sources by integrating the Microsoft Access database engine and the ability to take advantage of investments in commercial applications. The Microsoft Visual InterDev(R) development system includes integrated, team-based development tools for building Web-based applications based on HTML, Script, and components written in any language. Microsoft Visual J++ development system for Java contains a high productivity Integrated Development Environment and a collection of integrated components to create, test, tune, and deploy Java code on multiple platforms. Microsoft Visual Studio(R) development system for Windows-based development is a suite of developer tools enabling developers to build components and applications 4 using Visual Basic, Visual C++, Microsoft Visual FoxPro(R) database development system, Visual InterDev, and Visual J++. Developers can subscribe to the Microsoft Developer Network (MSDN(R)) information service and receive periodic updates via CD-ROMs, magazines, and several online information services. In addition, Microsoft receives certification fees through the Microsoft Certified Professional (MCP) program, a program that provides credentials for those who have demonstrated in-depth knowledge of at least one Microsoft product. Enterprise Services. Microsoft Enterprise Services assist organizations with every stage of technology planning, building, deployment, and support. Specializing in real-life IT solutions for the enterprise, Microsoft offers a full range of consulting services for advance technology requirements, including custom solutions services, enterprise application planning, architecture and design services, and proof-of-concept services. The Company provides product support services aligned to the customer segments, partner segments, and communities. Support offerings include the Alliance program, tailored for large enterprises running mission-critical applications on Microsoft platforms; the Premier program for enterprises; the Authorized Premier Support for all types of businesses who work jointly with Microsoft and Microsoft Gold Certified Partners; the Professional program for IT professionals, developers, and OEMs; and the Personal program for home users, which provides free online self-help resources and paid assisted phone support. Consumer Software, Services, and Devices -------------------------------------------------------------------------------- Consumer Software, Services, and Devices includes MSN Internet access, MSN network services, PC and online games, Xbox, learning and productivity software, mobility and embedded systems. MSN Internet Access. MSN Internet access is a Web-based online service. MSN provides easy and inexpensive access for users to a wide range of graphically rich online content. MSN Internet access includes MSN Explorer, the Internet software from Microsoft that makes it easier to get more from the Web. MSN Internet access subscribers can access their account from multiple sources, including a computer, television, Internet appliances, and Personal Data Assistants. MSN Network Services. MSN network service provides services on the Internet, encompassing MSN properties such as Homepage and Search, as well as other services. MSN Hotmail(R) is the world's leading free Web-based e-mail service. MSN Messenger Service is a free Internet messaging service that enables users to see when others are online and exchange instant messages with them. CNBC on MSN Money, located exclusively on MSN, is a complete online personal financial service that combines the award-winning finance tools and content from Microsoft with exclusive investment news and analysis from CNBC. MSN Music provides consumers with one place online to find old favorites, as well as discover new music, and delivers a high quality listening experience. MSN eShop is a one- stop online shopping resource. PC and Online Games. The Company offers a line of entertainment products from classic software games to online games, simulations, sport products, and strategy games. Microsoft Flight Simulator is a popular aircraft flight simulation product. Other games include Combat Flight Simulator, Age of Empires(R), MechWarrior(TM), Microsoft Links(R), and other sports and action titles. Zone.com is a gaming community on the Internet allowing multiplayer gaming competitions of Microsoft's popular CD-ROM games and classic card, board, and puzzle games. Xbox. Microsoft Xbox(TM), scheduled for North America release in November 2001, is Microsoft's future-generation video game console system that delivers high quality graphics and audio gameplay experiences and will ultimately enable new online gaming scenarios. Learning and Productivity Software. Learning titles include Microsoft Encarta(R) multimedia encyclopedia and Microsoft Bookshelf(R) CD-ROM reference library. The Encarta family of products includes a multimedia encyclopedia database with interactive information, an interactive world atlas with three- dimensional maps, a world English dictionary, and an online version with monthly updates. Microsoft Bookshelf is a multimedia reference library that gives users fast, easy access to reference resources. Titles for children include My Personal Tutor, a comprehensive, grade-based learning suite with TutorAssist learning technology that identifies a child's specific learning needs and offers instruction, and a series of 5 products based on the popular children's book and television series, Scholastic's The Magic School Bus(R). Microsoft's productivity offerings include Microsoft Works, an integrated software program that contains basic word processing, spreadsheet, and database capabilities that allows the easy exchange of information from one tool to another. Microsoft Money offers leading tools and resources to conduct a wide range of financial activities. The Works Suite provides a comprehensive collection of software, including Microsoft Works, Microsoft Word, Microsoft Money, Microsoft Encarta encyclopedia, Microsoft Picture It!(R) Publishing, and Microsoft Streets & Trips. Mobility and Embedded Systems. Microsoft develops a number of software platforms for mobile computing form factors. Products such as Pocket PC, Microsoft Mobile Explorer, and Microsoft Smartphone platform (currently codenamed Stinger) are designed to enable a variety of mobile scenarios. Microsoft's embedded offerings include two embedded operating systems, Microsoft Windows CE and Microsoft Windows NT Embedded, as well as device specific solutions. Microsoft Windows CE, a robust real-time embedded operating system, is targeted at small footprint, mobile 32-bit devices. Microsoft Windows NT Embedded, based on the desktop and server versions of Microsoft's operating systems, is targeted at higher-end embedded products and devices. Both embedded operating systems offer integrated tool sets to enable embedded system developers to quickly create sophisticated embedded device and application solutions. Microsoft Mobile Explorer enables secure mobile access to corporate or personal e-mail, corporate networks, and the Internet when connected to a wireless network. Microsoft Mobile Information Server is a scalable and reliable mobile applications server that provides enterprise customers and mobile operators with a rich platform for extending .NET Enterprise application and securely delivering real-time, wireless data to mobile devices. Consumer Commerce Investments -------------------------------------------------------------------------------- Consumer Commerce Investments include Expedia, Inc., the HomeAdvisor online real estate service, and the CarPoint online automotive service. Expedia, Inc. Expedia, Inc. operates Expedia.com, a leading online travel service in the United States with localized versions in Canada, Germany, and the United Kingdom. Expedia.com provides air, car, and hotel booking, vacation package and cruise offerings, destination information, and mapping. On July 16, 2001, USA Networks, Inc. (USA) announced an agreement to acquire a controlling interest in Expedia through the purchase of up to 37.5 million shares, approximately 75% of the current outstanding shares. If holders of more than 37.5 million Expedia shares elect to sell their shares to USA, there will be a pro rata reduction among all electing shareholders. Microsoft has agreed to transfer all of its 33.7 million shares and warrants, subject to pro-ration. It is expected that the transaction will close by December 31, 2001. HomeAdvisor online real estate service. The HomeAdvisor online real estate service is a complete guide to the home-buying process and provides comprehensive tools for finding homes and loans on the Internet. HomeAdvisor provides users with the information and knowledge needed to take control of the home-buying process. This includes customized search features, worksheets and calculators, and editorial content and home-buying advice. CarPoint online automotive service. The CarPoint online automotive service is the leading online automotive marketplace, visited by more than 7 million consumers each month. With details on more than 10,000 car models and 100,000 used vehicles, users can research and compare cars of virtually every make and model, identify local dealers, and receive instructions for post-purchase service and maintenance. Other -------------------------------------------------------------------------------- Hardware. The Company develops and markets several PC input devices including the Microsoft IntelliMouse(R) family of hand-held pointing devices that facilitate using the PC. The Company also markets several types of keyboards including the Microsoft Natural(R) Keyboard, an ergonomically designed keyboard. Microsoft sells various Microsoft SideWinder(R) game controllers and force feedback joysticks with realistic performance technology to use with PC games. 6 Microsoft Press. Microsoft Press offers comprehensive learning and training resources to help new users, power users, and professionals get the most from Microsoft technology through books, CDs, self-paced training kits, and videos that are created to accommodate different learning styles and preferences. Microsoft Press books are authored by professional and technical writers, both by Microsoft employees and independent authors. Equity Investments -------------------------------------------------------------------------------- The Company has entered into joint venture arrangements to take advantage of creative talent and content from other organizations. Microsoft owns 50 percent of MSNBC Cable L.L.C., a 24-hour cable news and information channel, and 50 percent of MSNBC Interactive News L.L.C., an interactive online news service. National Broadcasting Company (NBC) owns the remaining 50 percent of these two joint ventures. Microsoft owns 49 percent of Avanade Inc., a joint venture with Accenture Ltd, which offers solutions and services based on Windows 2000. Product Development The software industry is characterized by rapid technological change, which requires constant attention to computing technology trends, and shifting consumer demand, and rapid product innovation. The pace of change is accelerating as the computing needs of our customers move beyond the PC toward intelligent devices and appliances. Most of the Company's software products are developed internally. The Company also purchases technology, licenses intellectual property rights, and oversees third-party development and localization of certain products. Internal development enables Microsoft to maintain closer technical control over its products and gives the Company the freedom to designate which modifications and enhancements are most important and when they should be implemented. The Company has created a substantial body of proprietary development tools and has evolved development methodologies for creating and enhancing its products. These tools and methodologies are also designed to simplify a product's portability among different operating systems, microprocessors, or computing devices. Product documentation is generally created internally. The Company believes that a crucial factor in the success of a new product is getting it to market quickly to respond to new user needs or advances in intelligent devices, PCs, servers, and the Internet, without compromising product quality. The Company strives to become informed at the earliest possible time about changing usage patterns and hardware advances that may affect software design. Before releasing new software platforms, Microsoft provides to software vendors a range of development, training, testing resources, and guidelines for developing applications. To best serve the needs of users around the world, Microsoft "localizes" many of its products to reflect local languages and conventions and to improve the quality and usability of the product in international markets. Localizing a product might require modifying the user interface, altering dialog boxes, and translating text. In Japanese versions, for example, all user messages and documentation are in Japanese with monetary references in the Japanese yen. Various Microsoft products have been localized into more than 30 languages. During fiscal years 1999, 2000, and 2001, the Company spent $2.97 billion, $3.77 billion, and $4.38 billion, respectively, on product research and development activities excluding funding of joint venture activity. Those amounts represented 15.0%, 16.4%, and 17.3%, respectively, of revenue in each of those years. The Company is committed to continue high expenditures for research and product development. Microsoft .NET is Microsoft's platform for XML Web services. XML Web services allow applications to communicate and share data over the Internet, regardless of operating system or programming language. The Microsoft .NET platform includes a comprehensive family of products, built on XML and Internet industry standards, which provide for each aspect of developing, managing, using, and experiencing XML Web services. There are five areas where Microsoft is building the .NET platform today: Tools, Servers, XML Web Services, Clients, and .NET Experiences. In the Tools area, Visual Studio .NET and the 7 Microsoft .NET framework supply a complete solution for developers to build, deploy, and run XML Web services. They maximize the performance, reliability, and security of XML Web services. The .NET Enterprise Servers, including the Windows 2000 Server family, make up Microsoft .NET's server infrastructure for deploying, managing, and orchestrating XML Web services. Designed with mission- critical performance in mind, they provide enterprises with the agility they need to integrate their systems, applications, and partners through XML Web services, and the flexibility to adapt to changing business requirements. In addition to developers creating XML Web services, Microsoft is creating a core set of building block services that perform routine tasks and act as the backbone for developers to build upon. The first set of XML Web services being built, codenamed "HailStorm", is a group of user-centric services oriented around people, rather than specific devices, networks, or applications. HailStorm is based upon the Microsoft Passport user authentication system. With HailStorm, users receive relevant information, as they need it, delivered to the devices they are using, and based on preferences they have established. Clients are PCs, laptops, workstations, phones, handheld computers, Tablet PCs, game consoles, and other smart devices. These smart clients and devices use software that supports XML Web services, which enable users to access their data regardless of the location, type, and number of clients used. Smart clients and devices leverage XML Web services to create .NET experiences that allow users to access information across the Internet and from stand-alone applications in an integrated way. Some of the products that Microsoft is transitioning into .NET experiences are Office, MSN, bCentral, and Visual Studio .NET. Manufacturing -------------------------------------------------------------------------------- Microsoft contracts out most of its manufacturing activity to third parties. Outside manufacturers produce various retail software packaged products and hardware. There are other custom manufacturers Microsoft could use in the event outsourced manufacturing becomes unavailable from current vendors. The Company's CD-ROM manufacturing facilities are located in Puerto Rico. The Company has multiple sources for raw materials, supplies, and components and is often able to acquire component parts and materials on a volume discount basis. Quality control tests are performed on purchased parts, CD-ROMs, and other products. Operations -------------------------------------------------------------------------------- Microsoft manages all product fulfillment, licensing, and logistics services. The Company has regional operations centers in Ireland, Singapore, and the Greater Seattle area. The regional centers support all operations activities, including information processing, vendor management, logistics, and related supporting functions by geographical regions. The regional center in Dublin, Ireland supports the European, African, and Middle East regions, the center in Singapore supports the Asia Pacific region, and the center in the Greater Seattle area supports North and South America. Microsoft Licensing Incorporated (MSLI), a wholly-owned subsidiary in Reno, Nevada, manages the Company's original equipment manufacturer (OEM) and certain organizational licensing operations. Marketing and Distribution -------------------------------------------------------------------------------- The Company's sales and marketing group seeks to build long-term relationships with customers of Microsoft. The OEM sales group includes the sales force that works with original equipment manufacturers that preinstall Microsoft software on their PCs. In addition to the OEM channel, Microsoft has three major geographic sales and marketing organizations: the South Pacific and Americas; Europe, Middle East, and Africa; and Asia. 8 Finished Goods Channels -------------------------------------------------------------------------------- Distributors and Resellers. The Company licenses and sells its products in the finished goods channels primarily to and through independent non-exclusive distributors and resellers. Distributors and resellers include Ingram Micro, Tech Data, Software Spectrum, Corporate Software & Technology, SOFTBANK, Software House International, ASAP Software Express, and Tech Pacific Group. Microsoft has a network of field sales representatives and field support personnel who solicit orders from distributors and resellers and provide product training and sales support. Enterprise Accounts. The Microsoft Select program offers flexible software acquisition, licensing, and maintenance options specially customized to meet the needs of large multinational organizations. Targeted audiences include technology specialists and influential end users in large enterprises. Marketing efforts and fulfillment are generally coordinated with large account resellers. The Microsoft Open program is a licensing program that is targeted for small- and medium-sized organizations. It is available through the reseller channel and offers discounts based on initial purchase volumes. The Microsoft Enterprise Agreement program is a licensing program designed to provide a flexible licensing and service solution tailored to customers making a long-term licensing commitment. The agreements are designed to increase customer satisfaction by simplifying license administration, payment terms, and the contract process. Certified Partners. Microsoft Certified Partners are independent companies that offer their clients leading-edge technology through consulting, deployment, remote and on-site maintenance, helpdesk support, packaged software applications, hosting services, training, and more. Microsoft Certified Partners encompass a broad range of expertise and vendor affiliations and have experience ranging from networking, e-commerce, collaboration, business intelligence, and other leading edge disciplines. International Sales Sites. The Company has established marketing and/or support subsidiaries in more than 80 countries. Product is generally delivered by the Company's owned or outsourced manufacturing operations, which are located in the geographical region in which the product was sold. By organizing geographically, the Company is able to provide service to international channel customers and access to Microsoft professionals located in the same region to serve their specific needs. Subsidiaries have the responsibility for selling products to customers, managing licensing programs, and providing support to all types of customers based in international countries. The Company's international operations, both OEM and finished goods, are subject to certain risks common to foreign operations in general, such as governmental regulations, import restrictions, and foreign exchange rate fluctuations. Microsoft hedges a portion of its foreign exchange risk. OEM Channel -------------------------------------------------------------------------------- Microsoft operating systems are licensed primarily to OEMs under agreements that grant the OEMs the right to distribute copies of the Company's products with their computing devices, principally PCs. The Company also markets and licenses certain server operating systems, desktop applications, hardware devices, and consumer software programs to OEMs under similar arrangements. In almost all cases, the products are distributed under Microsoft trademarks. The Company has OEM agreements covering one or more of its products with virtually all of the major PC OEMs, including Acer, Actebis, Compaq, Dell, eMachines, Fujitsu, Fujitsu Siemens Computers, Gateway, Hewlett-Packard, IBM, Micron, NEC, Samsung, Sony, and Toshiba. A substantial amount of OEM business is also conducted with system builders, which are low-volume customized PC vendors. Advertising -------------------------------------------------------------------------------- The Company works closely with large advertising and direct marketing firms. Advertising, direct marketing, worldwide packaging, and marketing materials are targeted to various end-user segments. The Company uses broad consumer media (television, radio, the Internet, and business publications) and trade publications. Microsoft has programs under which qualifying resellers and OEMs are reimbursed for certain advertising expenditures. 9 Customers -------------------------------------------------------------------------------- The Company's customers include consumers, small- and medium-sized organizations, enterprises, educational institutions, ISPs, application developers, and OEMs. Most consumers of Microsoft products are individuals in businesses, government agencies, educational institutions, and at home. The consumers and organizations obtain Microsoft products primarily through resellers and OEMs, which include certain Microsoft products with their computing hardware. The Notes to Financial Statements (see Item 8) quantify customers that represent more than 10% of the Company's revenue. The Company's practice is to ship its products promptly upon receipt of purchase orders from its customers and, consequently, backlog is not significant. Competition -------------------------------------------------------------------------------- The software business is intensely competitive and subject to rapid technological change. As the company pursues its largest strategic initiative, Microsoft .NET, the Company could experience more intense competition during the transition from the traditional core businesses to its new products based on the .NET platform. The Company continues to face movements from PC-based applications to server-based applications or Web-based application hosting services, from proprietary software to open source software, and from PCs to Internet-based devices. A number of Microsoft's most significant competitors, including IBM, Sun Microsystems, Oracle, and AOL Time Warner, are collaborating with one another on various initiatives directed at competing with Microsoft. These initiatives relate in part to efforts to move software from individual PCs to centrally managed servers, which would present significant challenges to the Company's historical business model. Other competitive collaborative efforts include the development of new platform technologies that are intended to replicate much of the value of Microsoft Windows operating systems. New computing form factors, including non-PC information devices, are gaining popularity and competing with PCs running Microsoft's software products. Microsoft faces formidable competition in these new areas and in all areas of its current business activity, including competition from many companies much larger than Microsoft. The rapid pace of technological change, particularly in the area of Internet platforms and services, continually creates new opportunities for existing competitors and start-ups and can quickly render existing technologies less valuable. The Company also faces relentless competition from software pirates who unlawfully copy and distribute Microsoft's copyrighted software products, depriving the Company of large amounts of revenue on an annual basis. The Company's competitive position may be adversely affected by one or more of the following factors in the future, particularly in view of the fast pace of technological change in the computing industry. Desktop and Enterprise Software and Services -------------------------------------------- The Company's competitors include many software application vendors, such as IBM (Lotus), Oracle, Apple (Filemaker, Inc.), Sun Microsystems, Corel, Qualcomm, and local application developers in Europe and Asia. IBM and Corel have large installed bases with their spreadsheet and word processor products, respectively, and both have aggressive pricing strategies. Also, IBM and Apple preinstall certain of their application software products on various models of their PCs, competing directly with Microsoft's desktop application software. Sun Microsystems' Star Office is also very aggressive with its pricing, offering a free download from the Web or nominal charge for a CD. Additionally, Web- based application hosting services provide an alternative to PC-based applications such as Microsoft Office. Microsoft's operating system products face substantial competition from a wide variety of companies. Competitors such as IBM, Apple Computer, Sun Microsystems, and others are vertically integrated in both software development and hardware manufacturing and have developed operating systems that they preinstall on their own computers. Many of these operating system software products are also licensed to third-party OEMs for preinstallation on their computers. Microsoft's operating system products compete with UNIX-based operating systems from a wide range of companies, including IBM, Hewlett- Packard, Sun 10 Microsystems, and others. Variants of UNIX run on a wide variety of computer platforms and have gained increasing acceptance as desktop operating systems. With increased attention toward open source software, the Linux operating system has gained increasing acceptance as well. Several computer manufacturers preinstall Linux on PC servers and many leading software developers have written applications that run on Linux. Microsoft Windows operating systems are also threatened by alternative platforms such as those based on Internet browsing software and Java technology promoted by AOL Time Warner and Sun Microsystems. The Company competes in the business of providing enterprise-wide computing solutions with several competitors who enjoy a larger share of sales and larger installed bases. Many companies offer operating system software for mainframes and midrange computers, including IBM, Hewlett-Packard, and Sun Microsystems. Since legacy business systems are typically support-intensive, these competitors also offer substantial support services. Software developers that provide competing server applications for PC-based distributed client/server environments include Oracle, IBM, Computer Associates, Sybase, and Informix. There are also several software vendors who offer connectivity servers. As mentioned above, there are numerous companies and organizations that offer Internet and intranet server software, which compete against the Company's business systems. Additionally, IBM has a large installed base of Lotus Notes and cc:Mail, both of which compete with the Company's collaboration and e-mail products. The Company's developer products compete against offerings from Borland, Macromedia, Oracle, Sun Microsystems, Sybase, Symantec, and other companies. Consumer Software, Services, and Devices ---------------------------------------- Microsoft's online services network, MSN, faces formidable competition from AOL Time Warner (including its CompuServe unit), Yahoo!, and a vast array of Web sites and portals that offer content of all types and e-mail, instant messaging, calendaring, chat, and search and shopping services, among other things. In addition, the ease of entry into Internet services has allowed numerous Web- based service companies to build significant businesses in areas such as e-mail, electronic commerce, Web search engines, directories, and information of numerous types. Competitors include AOL Time Warner, Yahoo!, Excite, Lycos, Infoseek, AltaVista, and many others. The Company's MSNBC joint ventures face considerable competition from other 24-hour cable and Internet news organizations such as CNN, CNN Headline News, and Fox News Network. MSNBC also competes with traditional news media such as newspapers, magazines, and broadcast TV. The Company's Consumer Group continues to see consolidation across the various entertainment and productivity segments in which Microsoft competes. Competitors include Vivendi (Havas), Intuit, Electronic Arts, The Learning Company, Infogrammes, and Logitech. Still other competitors own branded content, such as Disney and LucasArts. Additionally, PC-based games and the Company's future Xbox compete and will compete head-to-head against games created for proprietary systems such as the Nintendo GameCube and the Sony PlayStation. Game developers like Electronic Arts, Namco, Midway, Activision, Konami, THQ, to name a few, are both partners and competitors in the games software development segment. Microsoft faces many competitors in the Mobile Devices space, including Palm, Symbian, Nokia, and Openwave. The embedded operating system market is highly fragmented with many competitive offerings. Key competitors include Wind River and versions of embeddable Linux from commercial Linux vendors such as Red Hat, Lineo, and Monta Vista. The largest competitor remains in-house operating systems developed by device manufacturers. However, this is changing as more device builders opt for commercial offerings as connectivity and richer features are required in devices. 11 Consumer Commerce Investments ----------------------------- In the United States, Expedia, Inc. competes with traditional travel distribution channels and online travel services such as Travelocity.com, Hotel Reservations Network, Priceline.com, CheapTickets.com, Biztravel.com, Worldres.com, and Trip.com. Expedia also competes with supplier-owned sites such as United.com, Delta.com, and Marriott.com. In addition, two new competitors owned by various airlines, Orbitz and Hotwire, emerged in fiscal year 2001. Internationally, Expedia competes with a different set of participants in each market. Microsoft faces many competitors in the online real estate service space, including AOL's House and Home channel and Homestore. The Company also faces many competitors in the online automotive service space, including Autobytel, CarsDirect, AOL autos, and Yahoo! autos. Other ----- PC input devices face substantial competition from computer manufacturers, since computers are typically sold with a keyboard and mouse, and other manufacturers of these devices. Microsoft Press competes in the retail book and eLearning markets with publishers that also create content on Microsoft technologies. A few of the retail competitors are Pearson, WROX, Sybex, and Wiley. The major eLearning competitors are Smartforce and NetG. Employees -------------------------------------------------------------------------------- As of June 30, 2001, the Company employed approximately 47,600 people on a full- time basis, 33,000 in the United States and 14,600 internationally. Of the total, 19,400 were in product research and development, 22,500 in sales, marketing, and support, 1,900 in manufacturing and distribution, and 3,800 in finance and administration. Microsoft's success is highly dependent on its ability to attract and retain qualified employees. Competition for employees is intense in the software industry. To date, the Company believes it has been successful in its efforts to recruit qualified employees, but there is no assurance that it will continue to be as successful in the future. None of the Company's employees is subject to collective bargaining agreements. The Company believes relations with its employees are excellent. Item 2. Properties The Company's corporate offices consist of approximately 7.9 million square feet of office building space located in King County, Washington. The Company is constructing three buildings with approximately 720,000 square feet of space that will be occupied in the Fall of 2001. The Company owns 4.8 million square feet of corporate campus space situated on slightly more than 300 acres of land and leases approximately 3.1 million square feet around the Puget Sound region. To accommodate expansion needs the Company has an option to purchase 150 acres of land in Issaquah, Washington, which can accommodate 2.95 million square feet of additional office space. The Company leases many sites domestically totaling approximately 3.0 million square feet of office building space. This includes the recent acquisition of the Great Plains facilities which totaled 425,000 square feet. The Company leases many sites internationally totaling approximately 4.1 million square feet. The Company's European operations center and localization division leases a 382,000 square-foot campus in Dublin, Ireland. The Company leases a 45,000 square-foot disk duplication facility in Humacao, Puerto Rico and leases a 36,000 square-foot facility in Singapore for its Asia Pacific operations center. The Company has office building space leased in the following locations: Tokyo, Japan 343,000 square feet; Unterschleissheim, Germany 253,000 square feet; United Kingdom campus 242,000 square feet; Les Ulis, France 229,000 square feet; and Beijing, China 115,000 square feet. The Company's facilities are fully used for current operations of all segments and suitable additional space is available to accommodate expansion needs. Item 3. Legal Proceedings See Notes to Financial Statements-Contingencies (Item 8) for information regarding legal proceedings. 12 Item 4. Submission of Matters to a Vote of Security Holders No matters were submitted to a vote of security holders during the fourth quarter of fiscal 2001. Executive Officers of the Registrant The executive officers of Microsoft as of September 10, 2001 were as follows:

Name Age Position with the Company William H. Gates, III 45 Chairman of the Board; Chief Software Architect Steven A. Ballmer 45 Chief Executive Officer Richard E. Belluzzo 47 President; Chief Operating Officer James E. Allchin 49 Group Vice President, Platforms Orlando Ayala 45 Group Vice President, Worldwide Sales, Marketing, and Services Robert J. (Robbie) Bach 39 Senior Vice President, Games Douglas J. Burgum 45 Senior Vice President, Business Solutions; President, Great Plains Division David W. Cole 39 Senior Vice President, Services Platform Division John G. Connors 42 Senior Vice President; Chief Financial Officer Jean-Philippe Courtois 41 Senior Vice President; President, Microsoft Europe, Middle East, and Africa Jon Stephan DeVaan 40 Senior Vice President, TV Division Richard P. Emerson 39 Senior Vice President, Corporate Development and Strategy Paul Flessner 42 Senior Vice President, .NET Enterprise Servers Kevin R. Johnson 40 Senior Vice President, U.S. Sales, Marketing, and Services Robert L. Muglia 41 Group Vice President, Personal Services Group Craig J. Mundie 52 Senior Vice President; Chief Technical Officer, Advanced Strategies and Policy William H. Neukom 59 Executive Vice President, Law and Corporate Affairs; Secretary Jeffrey S. Raikes 43 Group Vice President, Productivity and Business Services Richard F. Rashid 49 Senior Vice President, Research Steven J. Sinofsky 36 Senior Vice President, Office Brian Valentine 41 Senior Vice President, Windows David Vaskevitch 48 Senior Vice President; Chief Technical Officer, Business Platform Deborah N. Willingham 45 Senior Vice President, Human Resources

Mr. Gates co-founded Microsoft in 1975 and served as its Chief Executive Officer from the time the original partnership was incorporated in 1981 until January 2000, when he resigned as Chief Executive Officer and assumed the position of Chief Software Architect. Mr. Gates has served as Chairman of the Board since the Company's incorporation. Mr. Ballmer was named Chief Executive Officer and a director of the Company in January 2000. He had been President from July 1998 to February 2001. Previously, he had served as Executive Vice President, Sales and Support since February 1992. He was Senior Vice President, Systems Software from 1989 to 1992. From 1984 until 1989, Mr. Ballmer served as Vice President, Systems Software. He joined Microsoft in 1980. Mr. Belluzzo was named President and Chief Operating Officer in February 2001. He had been Group Vice President, Personal Services and Devices since August 2000. He joined Microsoft as Group Vice President, Consumer and Commerce in September 1999. Mr. Belluzzo had been Chairman of the Board 13 and Chief Executive Officer, Silicon Graphics, Inc. since January 1998. Prior to his employment at Silicon Graphics, Inc., Mr. Belluzzo was employed by the Hewlett-Packard Company for 22 years, serving since 1995 as Executive Vice President and General Manager of the computer organization. Mr. Allchin was named Group Vice President, Platforms in December 1999. He had been Senior Vice President, Platforms since March 1999. He was previously Senior Vice President, Personal and Business Systems since February 1996, Senior Vice President, Business Systems Division since November 1994, and had been Vice President, Business Systems Division since July 1991. Mr. Allchin joined Microsoft in 1991. Mr. Ayala was named Group Vice President, Worldwide Sales, Marketing, and Services in August 2000. He had been Senior Vice President, South Pacific and Americas since February 1998, and before holding that position, was Vice President of the developing markets of Africa, India, the Mediterranean and Middle East, Latin America, Southeast Asia and the South Pacific. He joined Microsoft in May 1991 as Senior Director of the Latin America Region. Mr. Bach was named Senior Vice President, Games in March 2000. He had been Vice President, Home and Retail since March 1999. Before holding that position, he had been Vice President, Learning, Entertainment and Productivity since 1996. Mr. Bach joined Microsoft in 1988. Mr. Burgum joined the Company upon Microsoft's acquisition of Great Plains Software, Inc. in April 2001. Mr. Burgum became Great Plains' first outside investor in March 1983. He was named President of Great Plains in 1984 and subsequently named Chairman and Chief Executive Officer. Mr. Cole was named Senior Vice President, Services Platform Division in August 2000. He had been Senior Vice President, Consumer Services since December 1999. Before holding that position, he had been Vice President, Consumer Windows since March 1999. Previously, he was Vice President, Web Client and Consumer Experience and Vice President, Internet Client and Collaboration. Mr. Cole joined Microsoft in 1986. Mr. Connors was named Senior Vice President and Chief Financial Officer in December 1999. He had been Vice President, Enterprise since March 1999. Mr. Connors had been Vice President, Information Technology, and Chief Information Officer since July 1996. He joined Microsoft in January 1989. Mr. Courtois was named Senior Vice President and President, Microsoft Europe, Middle East, and Africa in July 2000. He had been Vice President, Customer Marketing since July 1998. Before holding that position, he had been Vice President of Microsoft Europe since 1997 and General Manager for Microsoft France since 1994. Mr. Courtois joined Microsoft in 1984. Mr. DeVaan was named Senior Vice President, TV Division in December 1999. He had been Senior Vice President, Consumer and Commerce since September 1999. Mr. DeVaan had been Vice President, Consumer and Commerce since March 1999. He had been Vice President, Desktop Applications since 1995. Mr. DeVaan joined Microsoft in 1985. Mr. Emerson joined Microsoft in November 2000 as Senior Vice President, Corporate Development and Strategy. Prior to joining Microsoft, he was Managing Director and co-head of Technology and Telecommunications Advisory Services at international investment bank Lazard Freres & Co. LLC. He spent 12 years in San Francisco and New York with Lazard and Morgan Stanley, specializing in advising clients in the technology and telecommunications sectors on mergers, acquisitions, and strategic partnerships. Mr. Flessner was named Senior Vice President, .NET Enterprise Servers in December 1999. He had been Vice President, Database and Data Access. Since joining the Company, Mr. Flessner's primary responsibilities have been the development of Microsoft's database business. He assumed responsibility for the engineering of Microsoft SQL Server in 1995. He joined Microsoft in 1994. Mr. Johnson was named Senior Vice President, U.S. Sales, Marketing, and Services in August 2001. He had been Vice President, U.S. Sales, Marketing and Services. Mr. Johnson was named Vice President, Product Support Services in July 1998. He joined Microsoft in 1992. 14 Mr. Muglia was named Group Vice President, Personal Services Group in August 2000. He had been Group Vice President, Business Productivity since December 1999. He was named Senior Vice President, Business Productivity in March 1999 and was named Senior Vice President, Applications and Tools in February 1998. He had been Vice President, Server Applications since 1997 and was Vice President, Developer Tools since 1995. He joined Microsoft in January 1988. Mr. Mundie was named Senior Vice President and Chief Technical Officer, Advanced Strategies and Policy in August 2001. He was named Senior Vice President, Consumer Platforms in February 1996. He was named Senior Vice President, Consumer Systems in May 1995 and had been Vice President, Advanced Consumer Technology since July 1993. He joined Microsoft as General Manager, Advanced Consumer Technology in December 1992. Mr. Neukom was named Executive Vice President, Law and Corporate Affairs in October 1999. He had been Senior Vice President, Law and Corporate Affairs since February 1994. He joined Microsoft in 1985 as Vice President, Law and Corporate Affairs. Mr. Raikes was named Group Vice President, Productivity and Business Services in August 2000. He had been Group Vice President, Sales and Support since July 1998. Before holding that position, he had been Group Vice President, Sales and Marketing since July 1996. He was named Senior Vice President, Microsoft North America in January 1992 and had been Vice President, Office Systems since 1990. Mr. Raikes joined Microsoft in 1981. Mr. Rashid was named Senior Vice President, Research in May 2000. He had been Vice President, Research since July 1994. He joined Microsoft in September 1991. Mr. Sinofsky was named Senior Vice President, Office in December 1999. He had been Vice President, Office since December 1998. Mr. Sinofsky joined the Office team in 1994, increasing his responsibility with each subsequent release of the desktop suite. He joined Microsoft in July 1989. Mr. Valentine was named Senior Vice President, Windows in December 1999. He had been Vice President, Business and Enterprise since March 1999. He had been Vice President, Windows since December 1998. Before managing the Windows group, Mr. Valentine managed the server applications division and had been responsible for the Exchange product unit. He joined Microsoft in 1987. Mr. Vaskevitch was named Senior Vice President and Chief Technical Officer, Business Platform in August 2001. He was named Senior Vice President, Business Applications in March 2000. He had been Senior Vice President, Developer since December 1999. Before holding that position, he had been Vice President, Distributed Applications Platform. He joined Microsoft in 1986. Ms. Willingham was named Senior Vice President, Human Resources in February 2001. She had been Vice President, Human Resources since April 2000. Ms. Willingham had been Vice President, Business and Enterprise Division Marketing and was responsible for Windows operating system client and server marketing strategy and training, as well as for providing centralized marketing services for the Consumer Windows Marketing and Streaming Media Marketing teams. She joined Microsoft in 1993. 15 PART II Item 5. Market for Registrant's Common Stock and Related Stockholder Matters The Company's common stock is traded on The Nasdaq Stock Market under the symbol MSFT. On July 31, 2001, there were 112,001 registered holders of record of the Company's common stock. The Company has not paid cash dividends on its common stock. The high and low common stock prices per share were as follows:

Quarter Ended --------------------------------------------------------------------------------------------------------- Sept. 30 Dec. 31 Mar. 31 June 30 Year --------------------------------------------------------------------------------------------------------- 2000 Common stock price per share: High $100.75 $119.94 $118.63 $96.50 $119.94 Low 81.63 84.38 88.13 60.38 60.38 --------------------------------------------------------------------------------------------------------- 2001 Common stock price per share: High $ 82.00 $ 70.88 $ 64.69 $73.68 $ 82.00 Low 60.31 41.50 43.38 51.94 41.50 ---------------------------------------------------------------------------------------------------------

On April 11, 2001, the Company closed the acquisition of substantially all of the assets of iCommunicate Holding, Inc., a Delaware corporation ("iCommunicate"). Promptly thereafter, the Company issued an aggregate of 272,093 of its common shares to iCommunicate, which were subsequently distributed to iCommunicate's eleven shareholders in the liquidation of iCommunicate. All of the shares issued in this transaction were issued in a non-public offering pursuant to an exemption from the registration requirements of the Securities Act of 1933, as amended (the "1933 Act"), under Section 4(2) of the 1933 Act. On May 4, 2001, the Company issued an aggregate of 926,077 of its common shares pursuant to the merger of a subsidiary of the Company with Ensemble Studios Corporation, a Delaware corporation ("Ensemble"), owned by 45 shareholders. All of the shares issued in this transaction were issued in a non-public offering pursuant to an exemption from the registration requirements of the 1933 Act, under Section 4(2) of the 1933 Act. The above described sales were made without general solicitation or advertising. The Company has filed a Registration Statement on Form S-3 covering the resale of such securities issued pursuant to such acquisitions. All net proceeds from the sale of such securities will go to the selling shareholders who offer and sell their shares. The Company has not received and will not receive any proceeds from the sale of these common shares other than the assets and certain liabilities of iCommunicate and in connection with the merger with Ensemble. 16 Item 6. Selected Financial Data Financial Highlights (In millions, except earnings per share)

-------------------------------------------------------------------------------------------------------------- Year Ended June 30 1997 1998 1999 2000 2001(1) -------------------------------------------------------------------------------------------------------------- Revenue $11,936 $15,262 $19,747 $22,956 $25,296 Income before accounting change 3,454 4,490 7,785 9,421 7,721 Net income 3,454 4,490 7,785 9,421 7,346 Diluted earnings per share before accounting change 0.66 0.84 1.42 1.70 1.38 Diluted earnings per share 0.66 0.84 1.42 1.70 1.32 Cash and short-term investments 8,966 13,927 17,236 23,798 31,600 Total assets 14,387 22,357 38,625 52,150 59,257 Stockholders' equity 10,777 16,627 28,438 41,368 47,289 --------------------------------------------------------------------------------------------------------------

(1) Fiscal year 2001 includes an unfavorable cumulative effect of accounting change of $375 million or $0.06 per diluted share and $3.92 billion (pre- tax) in impairments of certain investments, primarily cable and telecommunication investments. 17 Item 7. Management's Discussion and Analysis of Results of Operations and Financial Condition Results of Operations for 1999, 2000, and 2001 -------------------------------------------------------------------------------- Microsoft develops, manufactures, licenses, and supports a wide range of software products for a multitude of computing devices. Microsoft software includes scalable operating systems for servers, personal computers (PCs), and intelligent devices; server applications for client/server environments; knowledge worker productivity applications; and software development tools. The Company's online efforts include the MSN network of Internet products and services and alliances with companies involved with broadband access and various forms of digital interactivity. Microsoft also licenses consumer software programs; sells hardware devices; provides consulting services; trains and certifies system integrators and developers; and researches and develops advanced technologies for future software products. Management's Discussion and Analysis contains statements that are forward- looking. These statements are based on current expectations and assumptions that are subject to risks and uncertainties. Actual results could differ materially because of factors discussed below under "Issues and Uncertainties." Revenue -------------------------------------------------------------------------------- The Company's revenue growth rate was 29% in fiscal 1999, 16% in fiscal 2000, and 10% in fiscal 2001. Revenue growth in fiscal 2001 was driven primarily by licensing of Microsoft Windows 2000 Professional, Microsoft SQL Server, and the other .NET Enterprise Servers. Consumer Software, Services, and Devices revenue also grew strongly. Partially offsetting those items was flat revenue growth from Windows Millennium Edition (Windows Me) and Windows 98 operating systems, reflecting the slowdown in consumer PC shipments and a higher mix of Windows 2000 Professional and Windows NT Workstation. Revenue growth in fiscal 2000 was driven by strong licensing of Microsoft Windows NT Workstation, Windows 2000 Professional, Windows NT Server, Windows 2000 Server, Microsoft Office 2000, and SQL Server. Consumer Software, Services, and Devices revenue also grew strongly. Partially offsetting those items was slower growth from Windows operating systems sold through the original equipment manufacturer (OEM) channel due to slow demand for business PCs throughout a significant portion of fiscal 2000. Revenue growth in fiscal 1999 reflected the continued adoption of Windows operating systems and Microsoft Office. In addition, the Company's estimate for future product returns was reduced by $250 million in fiscal 1999. In fiscal 1999, Microsoft made two changes related to the ratable recognition of revenue for a portion of its revenue for certain products. American Institute of Certified Public Accountants (AICPA) Statement of Position (SOP) 98-9, Modification of SOP 97-2, Software Revenue Recognition, With Respect to Certain Transactions, requires companies to use the average sales price of each undelivered element of software arrangements to unbundle revenue. Prior authoritative accounting guidance allowed a comparison of the total price differential between a licensed product sold through different channels of distribution to derive the value of undelivered elements offered to customers acquiring product from one channel but not the other. Upon adoption of this new rule in the fourth quarter of fiscal 1999, the percentages of the total arrangement treated as unearned decreased. This change reduced the amount of Microsoft Windows and Microsoft Office sales treated as unearned and increased the amount of revenue recognized upon shipment. Additionally, as part of the Company's long range planning process and a review of product shipment cycles, it was determined that the life cycle of Windows should be extended from two years to three years. Product Revenue Microsoft has four segments: Desktop and Enterprise Software and Services; Consumer Software, Services, and Devices; Consumer Commerce Investments; and Other. The Management Discussion and Analysis presentation of revenue differs from that reported under the Company's Segment Information appearing in the Notes to Financial Statements because reconciling items are allocated to those segments. 18 Desktop and Enterprise Software and Services Desktop and Enterprise Software and Services revenue was $17.84 billion, $20.40 billion, and $22.41 billion in 1999, 2000, and 2001. Desktop and Enterprise Software and Services includes Desktop Applications; Desktop Platforms; and Enterprise Software and Services. Desktop Applications revenue was $7.77 billion, $9.30 billion, and $9.54 billion in 1999, 2000, and 2001. Desktop Applications includes revenue from Microsoft Office; Microsoft Project; Visio; client access licenses (CALs) for Windows NT Server and Windows 2000 Server, Exchange, and BackOffice; Microsoft Great Plains; and bCentral. In fiscal 2001, revenue from client access licenses increased 14% reflecting strong licensing growth of Windows NT Server and Windows 2000 Server CALs. Office revenue growth was flat during the year. In fiscal 2000 and 1999, revenue growth from Microsoft Office integrated suites, including the Premium, Professional, Small Business, and Standard Editions were very solid. Desktop Platforms revenue was $6.74 billion, $7.02 billion, and $8.04 billion in 1999, 2000, and 2001. Desktop Platforms includes revenue from Windows 2000 Professional, Windows NT Workstation, Windows Me, Windows 98, and other desktop operating systems. Fiscal 2001 revenue growth reflected the strong adoption of Windows 2000 Professional, partially offset by flat revenue growth from Windows Me and Windows 98 operating systems, reflecting the slowdown in consumer PC shipments and a higher mix of Windows 2000 Professional and Windows NT Workstation. In fiscal 2000, Desktop Platforms revenue growth was modest due to soft demand for business PCs during most of the year; a slowdown in shipments in anticipation of the post mid-year availability of Windows 2000 operating systems; and, as expected, a longer business migration cycle for the newest Windows operating system offerings. In fiscal 1999, Windows units licensed through the OEM channel, particularly Windows NT Workstation, increased strongly over the prior year. Organizational licensing of Windows NT Workstation and Windows 98 also contributed to the growth. Enterprise Software and Services revenue was $3.33 billion, $4.08 billion, and $4.83 billion in 1999, 2000, and 2001. Enterprise Software and Services includes Enterprise Platforms, Server Applications, Developer Tools and Services, and Enterprise Services. As a result of the continued adoption of Microsoft's .NET Enterprise Server offerings in fiscal 2001, Server Applications revenue increased 31% versus the prior year. Enterprise Services revenue, representing consulting and product support services, was up 34% compared to fiscal 2000. Enterprise Platforms, which includes Windows 2000 Server and Windows NT Server operating systems, increased 10% while revenue from Developer Tools and Services was flat with the prior year. In fiscal 2000, Enterprise Platforms revenue growth was particularly strong led by increased adoption by customers of Windows NT Server and Windows 2000 Server. Revenue from Server Applications grew strongly, largely due to the strong success of SQL Server 7.0. Software Developer Tools and Services revenue declined, due to increased suite licensing versus stand-alone licenses, and the lack of a release upgrade of the Visual Studio development system. In fiscal 1999, the revenue growth rate for Windows NT Server was healthy. Revenue from Server Applications grew strongly, reflecting, in part, the release of SQL Server 7.0. The Visual Studio 6.0 development system drove healthy Developer Tools and Services revenue growth. Consulting services revenue rose substantially. Consumer Software, Services, and Devices Consumer Software, Services, and Devices revenue was $1.19 billion, $1.63 billion, and $1.95 billion in 1999, 2000, and 2001. Consumer Software, Services, and Devices includes MSN Internet access; MSN network service; WebTV Internet access and services; PC and online games; learning and productivity software; mobile and wireless devices; and embedded systems. In fiscal 2001, revenue from MSN network services grew strongly in light of the decline in the online advertising market. MSN Internet access revenue also grew solidly as a result of an increased subscriber base, partially offset by a decline in the average revenue per subscriber due to a larger mix of subscribers contracted under rebate programs. Revenue from embedded systems grew strongly from the prior year, while learning and productivity software revenue and PC and online games revenue declined, reflecting softness in the overall consumer market. In fiscal 2000, online revenue growth was very strong and reflected higher subscriber totals, offset by lower net prices for Internet access subscriptions compared to the prior year. Additionally, strong sell-through of entertainment software produced robust revenue growth. In fiscal 1999, online advertising revenue rose substantially and Internet access revenue increased moderately. 19 Consumer Commerce Investments Consumer Commerce Investments revenue was $62 million, $182 million, and $299 million in 1999, 2000, and 2001. Consumer Commerce Investments include Expedia, Inc., the HomeAdvisor online real estate service, and the CarPoint online automotive service. Acquisitions of Travelscape.com and VacationSpot.com by Expedia, Inc., and increased product offerings from Expedia led to the strong revenue growth in fiscal 2001. The increased overall reach of all properties led to the strong revenue growth in fiscal 2000 and 1999. On July 16, 2001, USA Networks, Inc. (USA) announced an agreement to acquire a controlling interest in Expedia through the purchase of up to 37.5 million shares, approximately 75% of the current outstanding shares. If holders of more than 37.5 million Expedia shares elect to sell their shares to USA, there will be a pro rata reduction among all electing shareholders. Microsoft has agreed to transfer all of its 33.7 million shares and warrants, subject to pro-ration. It is expected that the transaction will close by December 31, 2001. Other Other revenue was $653 million, $754 million, and $630 million in 1999, 2000, and 2001. Other primarily includes Hardware and Microsoft Press. Lower sales of gaming devices and other hardware peripherals as a result of weakness in the consumer market caused the decline in revenue in fiscal 2001. Continued success of the Company's new hardware device offerings led to the revenue growth in fiscal 2000. Revenue from hardware devices and Microsoft Press was relatively flat in fiscal 1999. Distribution Channels Microsoft distributes its products primarily through OEM licenses, organizational licenses, online services and products, and retail packaged products. OEM channel revenue represents license fees from original equipment manufacturers who preinstall Microsoft products, primarily on PCs. Microsoft has three major geographic sales and marketing regions: the South Pacific and Americas Region; the Europe, Middle East, and Africa Region; and the Asia Region. Sales of organizational licenses and packaged products via these channels are primarily to and through distributors and resellers. OEM revenue was $6.40 billion in 1999, $7.01 billion in 2000, and $7.86 billion in 2001. Although total licenses were impacted by a slowdown in PC shipments in fiscal 2001, the mix of the higher priced Windows 2000 Professional and Windows NT Workstation in the OEM channel increased substantially resulting in higher average revenue per license. The relatively low growth rate in fiscal 2000 was due to lower business PC shipment growth, especially as a result of the soft demand for business PCs and component shortages for part of the year. These issues combined with post mid-year availability of Windows 2000 Professional resulted in lower revenue growth. Average earned revenue per license also declined compared to the prior year, due in part to a mix shift to the lower- priced Windows 98 operating system reflecting the softness in demand for business PCs and lower prices on operating systems licensed through certain OEM channel sectors. In fiscal 1999, PC shipment growth coupled with an increased penetration of higher value 32-bit operating systems drove the OEM revenue increases. South Pacific and Americas Region revenue was $7.25 billion, $8.33 billion, and $9.52 billion in 1999, 2000, and 2001. In fiscal 2001, revenue growth, principally in the United States, was led by strong licensing of Windows 2000 Professional and the family of .NET Enterprise Servers, particularly SQL Server 2000 and Exchange 2000 Server. Revenue from Enterprise services and MSN subscription and services grew strongly. In fiscal 2000, Office 2000 integrated suites, Windows 2000 Server, online revenue, and SQL Server sales were the primary drivers of the revenue growth. Strong retail sales of hardware devices and consumer software also contributed to the growth over the prior year. Revenue growth was particularly strong in Latin America and Australia, moderate in Canada, and modest in the United States. In fiscal 1999, server applications, Windows NT Server, Windows NT Workstation, and Microsoft Office all exhibited solid year-over-year growth rates. Organizational licensing activity was strong. Revenue growth was solid in the United States and moderate in Latin America and the South Pacific. Europe, Middle East, and Africa Region revenue was $4.33 billion, $5.02 billion, and $4.86 billion in 1999, 2000, and 2001. In fiscal 2001, weakening local currencies negatively impacted translated revenue compared to the prior year. Revenue in the region would have increased 6% if foreign exchange rates were constant with those of the prior year. Revenue from Windows 2000 Professional and the .NET Enterprise Server family of products was very healthy. In fiscal 2000, retail sales of Windows operating systems and Office licensing produced moderate growth in the region. Growth from SQL Server licensing, new 20 hardware device offerings, and entertainment software was especially strong. Revenue growth, measured in constant dollars, was very healthy in Germany and Italy, robust in the Middle East, and low in the United Kingdom. In fiscal 1999, all major products grew strongly over the prior year. Revenue growth was solid in the United Kingdom, Germany, and France, and was particularly high in Sweden, the Netherlands, and Spain. Asia Region revenue was $1.78 billion in 1999, $2.60 billion in 2000, and $3.06 billion in 2001. In fiscal 2001, the region's growth rate reflected strong revenue from localized versions of Microsoft Office 2000 and Microsoft Office XP, especially the Office Personal suite. The growth was also attributable to Windows 2000 Professional and .NET Server applications licensing. Revenue growth was particularly strong in Korea and the greater China region, resulting from advantageous economic conditions as well as successful anti-piracy efforts. In fiscal 2000, the region's growth rate reflected strong performance resulting from improved local economic conditions. Revenue growth was also influenced by robust growth of localized versions of Microsoft Office 2000, especially the Office Personal Edition sold in Japan, Windows platform and server licensing, and strong adoption of SQL Server. Revenue grew strongly in nearly all countries in the Asia region. In fiscal 1999, Japan, Taiwan, China, Hong Kong, and Southeast Asia had moderate revenue growth, while revenue grew very strongly in Korea. The Company's operating results are affected by foreign exchange rates. Approximately 29%, 30%, and 27% of the Company's revenue was collected in foreign currencies during 1999, 2000, and 2001. Since a portion of local currency revenue is hedged and much of the Company's international manufacturing costs and operating expenses are also incurred in local currencies, the impact of exchange rates is partially mitigated. Operating Expenses -------------------------------------------------------------------------------- Cost of Revenue Cost of revenue as a percent of revenue was 14.3% in 1999, 13.1% in 2000, and 13.7% in 2001. In fiscal 2001, higher support and service costs associated with the MSN Internet access and MSN network services were partially offset by the lower relative costs associated with organizational licensing and the drop in the mix of packaged product versus the prior year. Cost of revenue in fiscal 2000 reflected lower costs associated with WebTV Networks' operations, partially offset by the growth in hardware peripherals costs. Cost of revenue as a percentage of revenue decreased in fiscal 1999 primarily due to the trend in mix shift to OEM and organizational licenses. Additionally, cost of revenue in 1999 was positively impacted by a reduction in estimates of obsolete inventory and other manufacturing costs of $67 million. Research and Development Microsoft continued to invest heavily in the future by funding research and development (R&D). In fiscal 2001, the increase in R&D expense was the result of higher headcount-related costs and investments in new product initiatives. The increase in fiscal 2000 was driven primarily by higher headcount-related costs. The increase in fiscal 1999 reflected higher development headcount- related costs offset by lower infrastructure and third-party development costs. Sales and Marketing In fiscal 2001, sales and marketing expenses as a percentage of revenue increased due to higher relative headcount-related costs, higher marketing and sales expenses associated with MSN, the Microsoft Agility advertising campaign, and other new sales initiatives. In fiscal 2000, sales and marketing expenses as a percentage of revenue increased due to higher relative marketing costs associated with new product releases and online marketing. In fiscal 1999, sales and marketing expense as a percentage of revenue decreased due to lower relative sales expenses and lower relative marketing costs. General and Administrative In fiscal 2001, general and administrative costs decreased due to a charge related to the settlement of the lawsuit with Caldera, Inc. recorded in fiscal 2000. Excluding this charge, general and administrative expenses in fiscal 2001 increased from the prior year due to higher headcount-related costs and legal fees. For fiscal 2000, besides the settlement of the lawsuit, general and administrative expenses also reflected increased legal fees and certain employee stock option-related expenses. The increase in fiscal year 1999 was attributable to higher legal fees, settlement costs, and headcount-related costs necessary to support the Company's expanding operations. 21 Non-operating Items, Investment Income/(Loss), and Income Taxes -------------------------------------------------------------------------------- Losses on equity investees and other incorporates Microsoft's share of income or loss from the MSNBC entities, Avanade, Wireless Knowledge, StarBand Communications, and other investments accounted for using the equity method. The increase in losses on equity investees and other in fiscal 2001 reflects an increase in the number of such investments during the year. In fiscal 2000 and 1999, losses on equity investees decreased reflecting smaller losses from the MSNBC entities. In fiscal 2001, the Company reported an investment loss of $36 million, a decrease in investment income of $3.36 billion versus fiscal 2000. Net recognized losses were $2.22 billion in fiscal 2001, reflecting $4.80 billion in impairments of certain investments, primarily in the cable and telecommunication industries, and $592 million of net losses attributable to derivative instruments. These losses were partially offset by higher net gains from the sales of investments, including a gain from Microsoft's investment in Titus Communications (which was merged with Jupiter Telecommunications) and the closing of the sale of Transpoint to CheckFree Holdings Corp. Interest and dividend income increased $591 million from the prior year, reflecting a larger investment portfolio. In fiscal years 2000 and 1999, investment income increased primarily as a result of a larger investment portfolio generated by cash from operations coupled with realized gains from the sale of securities. The effective tax rate for fiscal 2001 was 33%. The effective tax rate for fiscal 2000 was 34%. Excluding the impact of the gain on the sale of Softimage, Inc., the effective tax rate for fiscal 1999 was 35%. Accounting Change -------------------------------------------------------------------------------- Effective July 1, 2000, Microsoft adopted Statement of Financial Accounting Standards (SFAS) 133, Accounting for Derivative Instruments and Hedging Activities, which establishes accounting and reporting standards for derivative instruments, including certain derivative instruments embedded in other contracts and for hedging activities. All derivatives, whether designated in hedging relationships or not, are required to be recorded on the balance sheet at fair value. If the derivative is designated as a fair value hedge, the changes in the fair value of the derivative and the hedged item are recognized in earnings. If the derivative is designated as a cash flow hedge, changes in the fair value of the derivative are recorded in other comprehensive income (OCI) and are recognized in the income statement when the hedged item affects earnings. The adoption of SFAS 133 resulted in a cumulative pre-tax reduction to income of $560 million ($375 million after-tax) and a cumulative pre-tax reduction to OCI of $112 million ($75 million after-tax). The reduction to income was mostly attributable to a loss of approximately $300 million reclassified from OCI for the time value of options and a loss of approximately $250 million reclassified from OCI for derivatives not designated as hedging instruments. The reduction to OCI was mostly attributable to losses of approximately $670 million on cash flow hedges offset by the reclassifications out of OCI of the approximately $300 million loss for the time value of options and the approximately $250 million loss for derivative instruments not designated as hedging instruments. Financial Condition -------------------------------------------------------------------------------- The Company's cash and short-term investment portfolio totaled $31.60 billion at June 30, 2001. The portfolio consists primarily of fixed-income securities, diversified among industries and individual issuers. Microsoft's investments are generally liquid and investment grade. The portfolio is invested predominantly in U.S. dollar denominated securities, but also includes foreign currency positions in order to diversify financial risk. The portfolio is primarily invested in short-term securities to minimize interest rate risk and facilitate rapid deployment for immediate cash needs. Cash flow from operations was $13.42 billion in fiscal 2001, an increase of $2.00 billion from the prior year. The increase was primarily attributable to the growth in revenue and other changes in working capital, partially offset by the decrease in the stock option income tax benefit, reflecting decreased stock option exercises by employees. Cash used for financing was $5.59 billion in fiscal 2001, an increase of $3.39 billion from the prior year. The increase primarily reflects the repurchase of put warrants in fiscal 2001, compared to the sale of put warrants in the prior fiscal year, as well as an increase in common stock repurchased. All outstanding put warrants were either retired or exercised during fiscal 2001. During fiscal 22 2001, the Company repurchased 89.0 million shares. Cash used for investing was $8.73 billion in fiscal 2001, a decrease of $658 million from the prior year. In fiscal 2000, cash flow from operations was $11.43 billion, a decrease of $720 million from the prior year, reflecting working capital changes partially offset by the increase in the stock option income tax benefit. Cash used for financing was $2.19 billion in fiscal 2000, an increase of $1.33 billion from the prior year, reflecting an increase in common stock repurchased versus the prior year. During fiscal 2000, the Company repurchased 55.2 million shares. Cash used for investing was $9.39 billion in fiscal 2000, a decrease of $808 million from the prior year. In fiscal 1999, cash flow from operations was $12.15 billion, an increase of $3.78 billion from the prior year, reflecting the growth in revenue and the increase in the stock option income tax benefit. Cash used for financing was $862 million in fiscal 1999, a decrease of $137 million from the prior year. During fiscal 1999, the Company repurchased 44.9 million shares. Cash used for investing was $10.20 billion in fiscal 1999, an increase of $3.00 billion from the prior year, reflecting the growth in the investment portfolio. Microsoft has no material long-term debt. Stockholders' equity at June 30, 2001 was $47.29 billion. Microsoft will continue to invest in sales, marketing, and product support infrastructure. Additionally, research and development activities will include investments in existing and advanced areas of technology, including using cash to acquire technology. Additions to property and equipment will continue, including new facilities and computer systems for R&D, sales and marketing, support, and administrative staff. Commitments for constructing new buildings were $181 million on June 30, 2001. Cash will also be used for strategic opportunities. In addition, cash will be used to repurchase common stock to provide shares for employee stock option and purchase plans. Since fiscal 1990, Microsoft has repurchased 854 million common shares while 2.12 billion shares were issued under the Company's employee stock option and purchase plans. The market value of all outstanding stock options was $66 billion as of June 30, 2001. During December 1996, Microsoft issued 12.5 million shares of 2.75% convertible exchangeable preferred stock. The Company's convertible preferred stock matured on December 15, 1999. Each preferred share was converted into 1.1273 common shares. Management believes existing cash and short-term investments together with funds generated from operations should be sufficient to meet operating requirements. The Company's cash and short-term investments are available for strategic investments, mergers and acquisitions, and other potential large-scale needs and to fund the share repurchase program. Microsoft has not paid cash dividends on its common stock. Recently Issued Accounting Standards -------------------------------------------------------------------------------- In June 2001, the Financial Accounting Standards Board issued SFAS 141, Business Combinations, and SFAS 142, Goodwill and Other Intangible Assets. SFAS 141 requires business combinations initiated after June 30, 2001 to be accounted for using the purchase method of accounting. It also specifies the types of acquired intangible assets that are required to be recognized and reported separately from goodwill. SFAS 142 will require that goodwill and certain intangibles no longer be amortized, but instead tested for impairment at least annually. SFAS 142 is required to be applied starting with fiscal years beginning after December 15, 2001, with early application permitted in certain circumstances. The Company plans to early adopt SFAS 142 in fiscal 2002 and does not expect any impairment of goodwill upon adoption. Goodwill amortization was approximately $300 million in fiscal 2001 and approximately $225 million in fiscal 2000. Issues and Uncertainties -------------------------------------------------------------------------------- While Microsoft management is optimistic about the Company's long-term prospects, the following issues and uncertainties, among others, should be considered in evaluating its growth outlook. Rapid Technological Change and Competition Rapid change, uncertainty due to new and emerging technologies, and fierce competition characterize the software industry, which means that Microsoft's market position is always at risk. Microsoft's ability to maintain its current market share may depend upon the Company's ability to satisfy customer requirements, enhance existing products, develop and introduce new products and achieve market acceptance of such products. This process grows more challenging as the pace of change continues to accelerate. Open source 23 software, new computing devices, new microprocessor architectures, the Internet, and Web-based computing models are among the competitive challenges the Company must meet. If Microsoft does not successfully identify new product opportunities and develop and bring new products to market in a timely and cost-efficient manner, the Company's business growth will suffer and demand for its products will decrease. Future Initiatives The Company plans to continue to make significant investments in software research and development including Microsoft .NET, "HailStorm", Xbox, wireless technologies, digital devices, television, and small business. It is anticipated that these investments in research and development will increase over historical spending levels. Significant revenue from these product opportunities may not be achieved for a number of years, if at all. PC Growth Rates The nature of the PC marketplace is changing in ways that may reduce Microsoft's software sales and revenue growth. Overall market demand for PCs can significantly impact Microsoft's revenue growth. Recently, manufacturers have sought to reach more consumers by developing and producing lower cost PCs - PCs that come without pre-installed software or contain software with reduced functionality. In addition to the influx of low-cost PCs, a market for handheld computing and communication devices has developed. While these devices are not as powerful or versatile as PCs, they threaten to erode sales growth in the market for PCs with pre-installed software. This may affect Microsoft's revenue growth because manufacturers may choose not to install Microsoft software in these low-cost PCs or consumers may purchase alternative intelligent devices that do not use Microsoft software. These lower-priced devices require Microsoft to provide lower-priced software with a subset of the original functionality. As a result, the Company may generate less revenue from the sale of software produced for these devices than from the sale of software for PCs. Product Development The software industry is inherently complex. New products and product enhancements can require long development and testing periods. Significant delays in new product releases or significant problems in creating new products could damage Microsoft's business. The Company anticipates that Windows XP and Xbox will be released in fiscal 2002. Delays in either product may adversely affect revenue and net income. Prices The competitive factors described above may require Microsoft to lower product prices to meet competition, reducing the Company's revenue and net income. Earnings Process An increasingly higher percentage of the Company's revenue is subject to ratable recognition, which impacts the timing of revenue and earnings recognition. Ratable revenue recognition may be required for additional products, depending on specific license terms and conditions. Also, maintenance and new subscription programs are increasing in popularity. Employee Compensation Microsoft employees currently receive salaries, incentive bonuses, other benefits, and stock options. New government regulations, poor stock price performance, or other factors could diminish the value of the option program to current and prospective employees and require the Company to pay higher salaries and other cash compensation. International Operations Microsoft develops and sells products throughout the world. The prices of the Company's products in countries outside of the United States are generally higher than the Company's prices in the United States because of the cost incurred in localizing software for non-U.S. markets. The costs of producing and selling the Company's products in these countries are also higher. Pressure to globalize Microsoft's pricing structure might require that the Company reduce the sales price of its software in other countries, even though the costs of the software continue to be higher than in the United States. Unfavorable changes in software "piracy" trade protection laws, policies and measures, and other regulatory requirements affecting trade and investment; unexpected changes in regulatory requirements for software; social, political, labor, or economic conditions in a specific country or region; difficulties in staffing and managing foreign 24 operations; and potential adverse foreign tax consequences; among other factors, could also have an impact on the Company's business and results of operations outside of the United States. Intellectual Property Rights Microsoft diligently defends its intellectual property rights, but unlicensed copying of software represents a loss of revenue to the Company. While this adversely affects U.S. revenue, revenue loss is even more significant outside of the United States, particularly in countries where laws are less protective of intellectual property rights. Throughout the world, Microsoft actively educates consumers on the benefits of licensing genuine products and educates lawmakers on the advantages of a business climate where intellectual property rights are protected. However, continued efforts may not affect revenue positively. Litigation Litigation regarding intellectual property rights, patents, and copyrights occurs in the software industry. In addition, there are government regulation and investigation risks along with other general corporate legal risks. The Company is a defendant in a lawsuit filed by the Antitrust Division of the U.S. Department of Justice and a group of eighteen state Attorneys General alleging violations of the Sherman Act and various state antitrust laws. After the trial, the District Court entered Findings of Fact and Conclusions of Law stating that Microsoft had violated Sections 1 and 2 of the Sherman Act and various state antitrust laws. A Judgment was entered on June 7, 2000 ordering, among other things, the breakup of Microsoft into two companies. The Judgment was stayed pending an appeal. On June 28, 2001, the U.S. Court of Appeals for the District of Columbia Circuit affirmed in part, reversed in part, and vacated the Judgment in its entirety and remanded the case to the District Court for a new trial on one Section 1 claim and for entry of a new judgment consistent with its ruling. In its ruling, the Court of Appeals substantially narrowed the bases of liability found by the District Court, but affirmed some of the District Court's conclusions that Microsoft had violated Section 2. On September 6, 2001, the plaintiffs announced that on remand they will not ask the Court to break Microsoft up, that they will seek imposition of conduct remedies, and that they will not retry the one Section 1 claim returned to the District Court by the Court of Appeals. On August 7, 2001, Microsoft petitioned the Supreme Court for a writ of certiorari to review the appellate court's ruling concerning its disqualification of the District Court judge. Microsoft may petition the Supreme Court to review other aspects of the appellate court's decision after final judgment is entered. In response to the Court of Appeal's decision, Microsoft has modified the terms of its agreements with computer manufacturers to permit them to remove Internet Explorer icons from Windows when the manufacturer wants to promote an alternative browser, and modifying other provisions of the agreements. While the Company cannot predict with certainty the final outcome of this matter, its resolution may result in additional changes to the Company's business practices and could affect how the Company develops and markets new products and services. In addition, while the Court of Appeals ruling vacated the remedies portion of the Judgment in its entirety, it is possible the District Court could enter a new judgment providing for certain remedies that would have a material adverse effect on the Company if the Company cannot obtain relief from such provisions on appeal. A large number of antitrust class action lawsuits have been initiated against Microsoft. These cases allege that Microsoft has competed unfairly and unlawfully monopolized alleged markets for operating systems and certain software applications and seek to recover alleged overcharges that the complaints contend Microsoft charged for these products. Although Microsoft believes the claims are without merit and is vigorously defending the cases, the Company cannot predict with certainty the outcome of these lawsuits. Future Growth Rate The revenue growth rate in 2002 may not approach the level attained in prior years. Because of the fixed nature of a significant portion of operating expenses, coupled with the possibility of slower revenue growth, operating margins in 2002 may decrease from those in 2001. In addition, with the anticipated introduction of Xbox in fiscal 2002, cost of revenue as a percentage of revenue may increase versus prior years. Item 7a. Quantitative and Qualitative Disclosures about Market Risk The Company is exposed to foreign currency, interest rate, and securities price risks. A portion of these risks is hedged, but fluctuations could impact the Company's results of operations and financial position. 25 The Company hedges the exposure of accounts receivable and a portion of anticipated revenue to foreign currency fluctuations, primarily with option contracts. The Company monitors its foreign currency exposures daily to maximize the overall effectiveness of its foreign currency hedge positions. Principal currencies hedged include the Euro, Japanese yen, British pound, and Canadian dollar. Fixed income securities are subject to interest rate risk. The portfolio is diversified and consists primarily of investment grade securities to minimize credit risk. The Company routinely uses options to hedge its exposure to interest rate risk in the event of a catastrophic increase in interest rates. Many securities held in the Company's equity and other investments portfolio are subject to price risk. The Company uses options to hedge its price risk on certain highly volatile equity securities. The Company uses a value-at-risk (VAR) model to estimate and quantify its market risks. The VAR model is not intended to represent actual losses in fair value, but is used as a risk estimation and management tool. Assumptions applied to the VAR model at June 30, 2000 and June 30, 2001 include the following: normal market conditions; Monte Carlo modeling with 10,000 simulated market price paths; a 97.5% confidence interval; and a 20-day estimated loss in fair value for each market risk category. Accordingly, 97.5% of the time the estimated 20- day loss in fair value would be nominal for foreign currency denominated investments and accounts receivable at June 30, 2000 and June 30, 2001, and would not exceed $211 million and $363 million at June 30, 2000 and June 30, 2001 for interest-sensitive investments or $1.02 billion and $520 million at June 30, 2000 and June 30, 2001 for equity securities. 26 Item 8. Financial Statements and Supplementary Data Income Statements (In millions, except earnings per share)

--------------------------------------------------------------------------------------------------------------- Year Ended June 30 1999 2000 2001 --------------------------------------------------------------------------------------------------------------- Revenue $19,747 $22,956 $25,296 Operating expenses: Cost of revenue 2,814 3,002 3,455 Research and development 2,970 3,772 4,379 Sales and marketing 3,238 4,126 4,885 General and administrative 715 1,050 857 --------------------------------------------------------------------------------------------------------------- Total operating expenses 9,737 11,950 13,576 --------------------------------------------------------------------------------------------------------------- Operating income 10,010 11,006 11,720 Losses on equity investees and other (70) (57) (159) Investment income/(loss) 1,951 3,326 (36) --------------------------------------------------------------------------------------------------------------- Income before income taxes 11,891 14,275 11,525 Provision for income taxes 4,106 4,854 3,804 --------------------------------------------------------------------------------------------------------------- Income before accounting change 7,785 9,421 7,721 Cumulative effect of accounting change (net of income taxes of $185) -- -- (375) --------------------------------------------------------------------------------------------------------------- Net income $ 7,785 $ 9,421 $ 7,346 --------------------------------------------------------------------------------------------------------------- Basic earnings per share: Before accounting change $ 1.54 $ 1.81 $ 1.45 Cumulative effect of accounting change -- -- (0.07) --------------------------------------------------------------------------------------------------------------- $ 1.54 $ 1.81 $ 1.38 --------------------------------------------------------------------------------------------------------------- Diluted earnings per share: Before accounting change $ 1.42 $ 1.70 $ 1.38 Cumulative effect of accounting change -- -- (0.06) --------------------------------------------------------------------------------------------------------------- $ 1.42 $ 1.70 $ 1.32 --------------------------------------------------------------------------------------------------------------- Weighted average shares outstanding: Basic 5,028 5,189 5,341 --------------------------------------------------------------------------------------------------------------- Diluted 5,482 5,536 5,574 ---------------------------------------------------------------------------------------------------------------

See accompanying notes. 27 Balance Sheets (In millions)

------------------------------------------------------------------------------------------------------- June 30 2000 2001 ------------------------------------------------------------------------------------------------------- Assets Current assets: Cash and equivalents $ 4,846 $ 3,922 Short-term investments 18,952 27,678 ------------------------------------------------------------------------------------------------------- Total cash and short-term investments 23,798 31,600 Accounts receivable 3,250 3,671 Deferred income taxes 1,708 1,949 Other 1,552 2,417 ------------------------------------------------------------------------------------------------------- Total current assets 30,308 39,637 Property and equipment, net 1,903 2,309 Equity and other investments 17,726 14,141 Other assets 2,213 3,170 ------------------------------------------------------------------------------------------------------- Total assets $52,150 $59,257 ------------------------------------------------------------------------------------------------------- Liabilities and stockholders' equity Current liabilities: Accounts payable $ 1,083 $ 1,188 Accrued compensation 557 742 Income taxes 585 1,468 Unearned revenue 4,816 5,614 Other 2,714 2,120 ------------------------------------------------------------------------------------------------------- Total current liabilities 9,755 11,132 ------------------------------------------------------------------------------------------------------- Deferred income taxes 1,027 836 ------------------------------------------------------------------------------------------------------- Commitments and contingencies Stockholders' equity: Common stock and paid-in capital--shares authorized 12,000; shares issued and outstanding 5,283 and 5,383 23,195 28,390 Retained earnings, including accumulated other comprehensive income of $1,527 and $587 18,173 18,899 ------------------------------------------------------------------------------------------------------- Total stockholders' equity 41,368 47,289 ------------------------------------------------------------------------------------------------------- Total liabilities and stockholders' equity $52,150 $59,257 -------------------------------------------------------------------------------------------------------

See accompanying notes. 28 Cash Flows Statements (In millions)

--------------------------------------------------------------------------------------------------------- Year Ended June 30 1999 2000 2001 --------------------------------------------------------------------------------------------------------- Operations Net income $ 7,785 $ 9,421 $ 7,346 Cumulative effect of accounting change, net of tax -- -- 375 Depreciation, amortization, and other noncash items 926 1,250 1,536 Net recognized (gains)/losses on investments (803) (1,732) 2,221 Stock option income tax benefits 3,107 5,535 2,066 Deferred income taxes (650) (425) (420) Unearned revenue 5,877 6,177 6,970 Recognition of unearned revenue (4,526) (5,600) (6,369) Accounts receivable (687) (944) (418) Other current assets (235) (775) (482) Other long-term assets (117) (864) (330) Other current liabilities 1,469 (617) 927 --------------------------------------------------------------------------------------------------------- Net cash from operations 12,146 11,426 13,422 --------------------------------------------------------------------------------------------------------- Financing Common stock issued 1,350 2,245 1,620 Common stock repurchased (2,950) (4,896) (6,074) Sales/(repurchases) of put warrants 766 472 (1,367) Preferred stock dividends (28) (13) -- Other, net -- -- 235 --------------------------------------------------------------------------------------------------------- Net cash used for financing (862) (2,192) (5,586) --------------------------------------------------------------------------------------------------------- Investing Additions to property and equipment (583) (879) (1,103) Purchases of investments (34,686) (42,290) (66,346) Maturities of investments 4,063 4,025 5,867 Sales of investments 21,006 29,752 52,848 --------------------------------------------------------------------------------------------------------- Net cash used for investing (10,200) (9,392) (8,734) --------------------------------------------------------------------------------------------------------- Net change in cash and equivalents 1,084 (158) (898) Effect of exchange rates on cash and equivalents 52 29 (26) Cash and equivalents, beginning of year 3,839 4,975 4,846 --------------------------------------------------------------------------------------------------------- Cash and equivalents, end of year $ 4,975 $ 4,846 $ 3,922 ---------------------------------------------------------------------------------------------------------

See accompanying notes. 29 Stockholders' Equity Statements (In millions)

------------------------------------------------------------------------------------------------------ Year Ended June 30 1999 2000 2001 ------------------------------------------------------------------------------------------------------ Convertible preferred stock Balance, beginning of year $ 980 $ 980 $ -- Conversion of preferred to common stock -- (980) -- ------------------------------------------------------------------------------------------------------ Balance, end of year 980 -- -- ------------------------------------------------------------------------------------------------------ Common stock and paid-in capital Balance, beginning of year 8,025 13,844 23,195 Common stock issued 2,338 3,554 5,154 Common stock repurchased (64) (210) (394) Sales/(repurchases) of put warrants 766 472 (1,367) Stock option income tax benefits 3,107 5,535 2,066 Other, net (328) -- (264) ------------------------------------------------------------------------------------------------------ Balance, end of year 13,844 23,195 28,390 ------------------------------------------------------------------------------------------------------ Retained earnings Balance, beginning of year 7,622 13,614 18,173 ------------------------------------------------------------------------------------------------------ Net income 7,785 9,421 7,346 Other comprehensive income: Cumulative effect of accounting change -- -- (75) Net gains on derivative instruments -- -- 634 Net unrealized investment gains/(losses) 1,052 (283) (1,460) Translation adjustments and other 69 23 (39) ------------------------------------------------------------------------------------------------------ Comprehensive income 8,906 9,161 6,406 Preferred stock dividends (28) (13) -- Immaterial pooling of interests -- 97 -- Common stock repurchased (2,886) (4,686) (5,680) ------------------------------------------------------------------------------------------------------ Balance, end of year 13,614 18,173 18,899 ------------------------------------------------------------------------------------------------------ Total stockholders' equity $28,438 $41,368 $47,289 ------------------------------------------------------------------------------------------------------

See accompanying notes. 30 Notes to Financial Statements Accounting Policies Accounting Principles The financial statements and accompanying notes are prepared in accordance with generally accepted accounting principles in the United States. Principles of Consolidation The financial statements include the accounts of Microsoft and its subsidiaries. Intercompany transactions and balances have been eliminated. Equity investments in which Microsoft owns at least 20% of the voting securities are accounted for using the equity method, except for investments in which the Company is not able to exercise significant influence over the investee, in which case, the cost method of accounting is used. Issuances of shares by a subsidiary are accounted for as capital transactions. Estimates and Assumptions Preparing financial statements requires management to make estimates and assumptions that affect the reported amounts of assets, liabilities, revenue, and expenses. Examples include provisions for returns, concessions and bad debts; and the length of product life cycles and buildings' lives. Actual results may differ from these estimates. Foreign Currencies Assets and liabilities recorded in foreign currencies are translated at the exchange rate on the balance sheet date. Translation adjustments resulting from this process are charged or credited to other comprehensive income. Revenue and expenses are translated at average rates of exchange prevailing during the year. Revenue Recognition Revenue from products licensed to original equipment manufacturers is recorded when OEMs ship licensed products while revenue from certain license programs is recorded when the software has been delivered and the customer is invoiced. Revenue from packaged product sales to and through distributors and resellers is recorded when related products are shipped. Maintenance and subscription revenue is recognized ratably over the contract period. Revenue attributable to undelivered elements, including technical support and Internet browser technologies, is based on the average sales price of those elements and is recognized ratably on a straight-line basis over the product's life cycle. When the revenue recognition criteria required for distributor and reseller arrangements are not met, revenue is recognized as payments are received. Costs related to insignificant obligations, which include telephone support for certain products, are accrued. Provisions are recorded for returns, concessions, and bad debts. Cost of Revenue Cost of revenue includes direct costs to produce and distribute product and direct costs to provide online services, consulting, product support, and training and certification of system integrators. Research and Development Research and development costs are expensed as incurred. Statement of Financial Accounting Standards (SFAS) 86, Accounting for the Costs of Computer Software to Be Sold, Leased, or Otherwise Marketed, does not materially affect the Company. Advertising Costs Advertising costs are expensed as incurred. Advertising expense was $804 million in 1999, $1.23 billion in 2000, and $1.36 billion in 2001. Income Taxes Income tax expense includes U.S. and international income taxes, plus the provision for U.S. taxes on undistributed earnings of international subsidiaries. Certain items of income and expense are not reported in tax returns and financial statements in the same year. The tax effect of this difference is reported as deferred income taxes. Financial Instruments The Company considers all liquid interest-earning investments with a maturity of three months or less at the date of purchase to be cash equivalents. Short-term investments generally mature between three months and six years from the purchase date. All cash and short-term investments are classified as available for sale and are recorded at market value using the specific identification method; unrealized gains and losses are reflected in other comprehensive income (OCI). 31 Equity and other investments include debt and equity instruments. Debt securities and publicly traded equity securities are classified as available for sale and are recorded at market using the specific identification method. Unrealized gains and losses (excluding other-than-temporary losses) are reflected in other comprehensive income. All other investments, excluding those accounted for using the equity method, are recorded at cost. Microsoft lends certain fixed income and equity securities to enhance investment income. Collateral and/or security interest is determined based upon the underlying security and the creditworthiness of the borrower. The fair value of collateral that Microsoft is permitted to sell or repledge was $499 million at June 30, 2001. There was no collateral that Microsoft was permitted to sell or repledge at June 30, 2000. Investments are considered to be impaired when a decline in fair value is judged to be other-than-temporary. The Company employs a systematic methodology that considers available evidence in evaluating potential impairment of its investments. In the event that the cost of an investment exceeds its fair value, the Company evaluates, among other factors, the duration and extent to which the fair value is less than cost; the financial health of and business outlook for the investee, including industry and sector performance, changes in technology, and operational and financing cash flow factors; and the Company's intent and ability to hold the investment. Once a decline in fair value is determined to be other-than-temporary, an impairment charge is recorded and a new cost basis in the investment is established. In 2001, the Company recognized $4.80 billion in impairments of certain investments, primarily in the cable and telecommunication industries. The Company uses derivative instruments to manage exposures to foreign currency, security price, and interest rate risks. The Company's objectives for holding derivatives are to minimize these risks using the most effective methods to eliminate or reduce the impact of these exposures. Foreign Currency Risk --------------------- Certain forecasted transactions and assets are exposed to foreign currency risk. The Company monitors its foreign currency exposures daily to maximize the overall effectiveness of its foreign currency hedge positions. Principal currencies hedged include the Euro, Japanese yen, British pound, and Canadian dollar. Options used to hedge a portion of forecasted international revenue for up to three years in the future are designated as cash flow hedging instruments. Options and forwards not designated as hedging instruments under SFAS 133 are also used to hedge the impact of the variability in exchange rates on accounts receivable and collections denominated in certain foreign currencies. Securities Price Risk --------------------- Strategic equity investments are subject to market price risk. From time to time, the Company uses and designates options to hedge fair values and cash flows on certain equity securities. The security, or forecasted sale thereof, selected for hedging is determined by market conditions, up-front costs, and other relevant factors. Once established, the hedges are not dynamically managed or traded, and are generally not removed until maturity. Interest Rate Risk ------------------ Fixed-income securities are subject to interest rate risk. The fixed-income portfolio is diversified and consists primarily of investment grade securities to minimize credit risk. The Company routinely uses options, not designated as hedging instruments, to hedge its exposure to interest rate risk in the event of a catastrophic increase in interest rates. Other Derivatives ----------------- In addition, the Company may invest in warrants to purchase securities of other companies as a strategic investment. Warrants that can be net share settled are deemed derivative financial instruments and are not designated as hedging instruments. For options designated either as fair value or cash flow hedges, changes in the time value are excluded from the assessment of hedge effectiveness. 32 Property and Equipment Property and equipment is stated at cost and depreciated using the straight-line method over the shorter of the estimated life of the asset or the lease term, ranging from one to 15 years. Computer software developed or obtained for internal use is depreciated using the straight-line method over the shorter of the estimated life of the software or three years. Intangible Assets Goodwill and other intangible assets are amortized using the straight-line method over their estimated period of benefit, ranging from three to seven years. The Company periodically evaluates the recoverability of intangible assets and takes into account events or circumstances that warrant revised estimates of useful lives or that indicate that an impairment exists. In June 2001, the Financial Accounting Standards Board issued Statement of Financial Accounting Standards (SFAS) 141, Business Combinations, and SFAS 142, Goodwill and Other Intangible Assets. SFAS 141 requires business combinations initiated after June 30, 2001 to be accounted for using the purchase method of accounting. It also specifies the types of acquired intangible assets that are required to be recognized and reported separately from goodwill. SFAS 142 will require that goodwill and certain intangibles no longer be amortized, but instead tested for impairment at least annually. SFAS 142 is required to be applied starting with fiscal years beginning after December 15, 2001, with early application permitted in certain circumstances. The Company plans to early adopt SFAS 142 in fiscal 2002 and does not expect any impairment of goodwill upon adoption. Goodwill amortization was approximately $300 million in fiscal 2001 and approximately $225 million in fiscal 2000. Reclassifications Certain reclassifications have been made for consistent presentation. Accounting Change Effective July 1, 2000, the Company adopted SFAS 133, Accounting for Derivative Instruments and Hedging Activities, which establishes accounting and reporting standards for derivative instruments, including certain derivative instruments embedded in other contracts and for hedging activities. All derivatives, whether designated in hedging relationships or not, are required to be recorded on the balance sheet at fair value. If the derivative is designated as a fair value hedge, the changes in the fair value of the derivative and of the hedged item attributable to the hedged risk are recognized in earnings. If the derivative is designated as a cash flow hedge, the effective portions of changes in the fair value of the derivative are recorded in other comprehensive income and are recognized in the income statement when the hedged item affects earnings. Ineffective portions of changes in the fair value of cash flow hedges are recognized in earnings. The adoption of SFAS 133 on July 1, 2000, resulted in a cumulative pre-tax reduction to income of $560 million ($375 million after-tax) and a cumulative pre-tax reduction to OCI of $112 million ($75 million after-tax). The reduction to income was mostly attributable to a loss of approximately $300 million reclassified from OCI for the time value of options and a loss of approximately $250 million reclassified from OCI for derivatives not designated as hedging instruments. The reduction to OCI was mostly attributable to losses of approximately $670 million on cash flow hedges offset by reclassifications out of OCI of the approximately $300 million loss for the time value of options and the approximately $250 million loss for derivative instruments not designated as hedging instruments. The net derivative losses included in OCI as of July 1, 2000 were reclassified into earnings during the twelve months ended June 30, 2001. The change in accounting from the adoption of SFAS 133 did not materially affect net income in 2001. Unearned Revenue A portion of Microsoft's revenue is earned ratably over the product life cycle or, in the case of subscriptions, over the period of the license agreement. End users receive certain elements of the Company's products over a period of time. These elements include items such as browser technologies and technical support. Consequently, Microsoft's earned revenue reflects the recognition of the fair value of these elements over the product's life cycle. Upon adoption of American Institute of Certified Public Accountants (AICPA) Statement of Position (SOP) 98-9, Modification of SOP 97-2, With Respect to 33 Certain Transactions, during the fourth quarter of fiscal 1999, the Company was required to change the methodology of attributing the fair value to undelivered elements. The percentages of undelivered elements in relation to the total arrangement decreased, reducing the amount of Windows and Office revenue treated as unearned, and increasing the amount of revenue recognized upon shipment. The percentage of revenue recognized ratably decreased from a range of 20% to 35% to a range of approximately 15% to 25% of Windows desktop operating systems. For desktop applications, the percentage decreased from approximately 20% to a range of approximately 10% to 20%. The ranges depend on the terms and conditions of the license and prices of the elements. In addition, in the fourth quarter of fiscal 1999, the Company extended the life cycle of Windows from two to three years based upon management's review of product shipment cycles. Product life cycles are currently estimated at 18 months for desktop applications. The Company also sells subscriptions to certain products via maintenance and certain organizational license agreements. At June 30, 2000 and 2001, Desktop Applications unearned revenue was $1.84 billion and $2.19 billion. Desktop Platforms unearned revenue was $2.34 billion and $2.59 billion. Enterprise Software and Services unearned revenue was $433 million and $413 million. Unearned revenue associated with Consumer Software, Services, and Devices, and Other was $200 million and $427 million at June 30, 2000 and 2001. Cash and Short-Term Investments --------------------------------------------------------------- In Millions / June 30 2000 2001 --------------------------------------------------------------- Cash and equivalents: Cash $ 849 $ 1,145 Commercial paper 1,986 894 Certificates of deposit 1,017 286 U.S. government and agency securities 729 400 Corporate notes and bonds 265 1,130 Municipal securities -- 67 --------------------------------------------------------------- Cash and equivalents 4,846 3,922 --------------------------------------------------------------- Short-term investments: Commercial paper 612 638 U.S. government and agency securities 7,104 7,322 Corporate notes and bonds 9,473 17,321 Municipal securities 1,113 1,703 Certificates of deposit 650 694 --------------------------------------------------------------- Short-term investments 18,952 27,678 --------------------------------------------------------------- Cash and short-term investments $23,798 $31,600 =============================================================== As of June 30, 2000 and 2001, cost approximated market for all classifications of cash and short-term investments. Realized gains and (losses) from cash and short-term investments were $150 million and $(131) million in 1999, $80 million and $(226) million in 2000, and $541 million and $(369) million in 2001. Property and Equipment ---------------------------------------------------------------- In Millions / June 30 2000 2001 ---------------------------------------------------------------- Land $ 176 $ 185 Buildings 1,387 1,584 Computer equipment and software 1,909 2,431 Other 842 1,075 ---------------------------------------------------------------- Property and equipment--at cost 4,314 5,275 Accumulated depreciation (2,411) (2,966) ---------------------------------------------------------------- Property and equipment--net $ 1,903 $ 2,309 ================================================================ During 1999, 2000, and 2001, depreciation expense, of which the majority related to computer equipment, was $483 million, $668 million, and $764 million. 34 Equity and Other Investments

Cost Unrealized Unrealized Recorded In Millions / June 30, 2000 Basis Gains Losses Basis --------------------------------------------------------------------------------------------------------------- Debt securities recorded at market, maturing: Within one year $ 498 $ 27 $ -- $ 525 Between 2 and 10 years 388 11 (3) 396 Between 10 and 15 years 775 14 (93) 696 Beyond 15 years 4,745 -- (933) 3,812 --------------------------------------------------------------------------------------------------------------- Debt securities recorded at market 6,406 52 (1,029) 5,429 --------------------------------------------------------------------------------------------------------------- Common stock and warrants 5,815 5,655 (1,697) 9,773 Preferred stock 2,319 -- -- 2,319 Other investments 205 -- -- 205 --------------------------------------------------------------------------------------------------------------- Equity and other investments $14,745 $5,707 $(2,726) $17,726 ===============================================================================================================

Cost Unrealized Unrealized Recorded In Millions / June 30, 2001 Basis Gains Losses Basis --------------------------------------------------------------------------------------------------------------- Debt securities recorded at market, maturing: Within one year $ 500 $ -- $ -- $ 500 Between 2 and 10 years 643 12 (3) 652 Between 10 and 15 years 513 -- (9) 504 Beyond 15 years 4,754 -- (829) 3,925 --------------------------------------------------------------------------------------------------------------- Debt securities recorded at market 6,410 12 (841) 5,581 --------------------------------------------------------------------------------------------------------------- Common stock and warrants 5,555 2,030 (285) 7,300 Preferred stock 881 -- -- 881 Other investments 379 -- -- 379 --------------------------------------------------------------------------------------------------------------- Equity and other investments $13,225 $2,042 $(1,126) $14,141 ===============================================================================================================

Debt securities include corporate and government notes and bonds and derivative securities. Debt securities maturing beyond 15 years are composed entirely of AT&T 5% convertible preferred debt with a contractual maturity of 30 years. The debt is convertible into AT&T common stock on or after December 1, 2000, or may be redeemed by AT&T upon satisfaction of certain conditions on or after June 1, 2002. Equity securities that are restricted for more than one year or not publicly traded are recorded at cost. At June 30, 2000 and 2001, the estimated fair value of these investments in excess of their recorded basis was $2.70 billion and $161 million, based on publicly available market information or other estimates determined by management. Realized gains and (losses) from equity and other investments (excluding impairments discussed previously) were $786 million and $(2) million in 1999, $1.94 billion and $(10) million in 2000, and $3.03 billion and $(23) million in 2001. Derivatives For the twelve months ended June 30, 2001, investment income included a net unrealized loss of $592 million, comprised of a $214 million gain for changes in the time value of options for fair value hedges, $211 million loss for changes in the time value of options for cash flow hedges, and $595 million loss for changes in the fair value of derivative instruments not designated as hedging instruments. Derivative gains and losses included in OCI are reclassified into earnings at the time forecasted revenue or the sale of an equity investment is recognized. During the twelve months ended June 30, 2001, $214 million of derivative gains were reclassified to revenue and $416 million of derivative losses were reclassified to investment income/(loss). The derivative losses reclassified to investment income/(loss) were offset by gains on the item being hedged. The Company estimates that $144 million of net derivative gains included in other comprehensive income will be reclassified into earnings within the next twelve months. 35 For instruments designated as hedges, hedge ineffectiveness, determined in accordance with SFAS 133, had no impact on earnings for the twelve months ended June 30, 2001. No fair value hedges or cash flow hedges were derecognized or discontinued for the twelve months ended June 30, 2001. Investment Income/(Loss) The components of investment income/(loss) are as follows:

In Millions / Year Ended June 30 1999 2000 2001 ---------------------------------------------------------------------------------------------------- Dividends $ 118 $ 363 $ 377 Interest 1,030 1,231 1,808 Net recognized gains/(losses) on investments 803 1,732 (2,221) ---------------------------------------------------------------------------------------------------- Investment income/(loss) $ 1,951 $ 3,326 $ (36) ==================================================================================================== Income Taxes The provision for income taxes consisted of:
In Millions / Year Ended June 30 1999 2000 2001 ---------------------------------------------------------------------------------------------------- Current taxes: U.S. and state $ 4,027 $ 4,744 $ 3,243 International 281 535 514 ---------------------------------------------------------------------------------------------------- Current taxes 4,308 5,279 3,757 Deferred taxes (202) (425) 47 ---------------------------------------------------------------------------------------------------- Provision for income taxes $ 4,106 $ 4,854 $ 3,804 ==================================================================================================== U.S. and international components of income before income taxes were:
In Millions / Year Ended June 30 1999 2000 2001 ---------------------------------------------------------------------------------------------------- U.S. $10,649 $11,860 $ 9,189 International 1,242 2,415 2,336 ---------------------------------------------------------------------------------------------------- Income before income taxes $11,891 $14,275 $11,525 ====================================================================================================

In 1999, the effective tax rate was 35.0%, excluding the impact of the gain on the sale of Softimage, Inc. In 2000, the effective tax rate was 34.0%, and included the effect of a 2.5% reduction from the U.S. statutory rate for tax credits and a 1.5% increase for other items. In 2001, the effective tax rate was 33.0%, and included the effect of a 3.1% reduction from the U.S. statutory rate for tax credits and a 1.1% increase for other items. The components of the differences between the U.S. statutory tax rate and the Company's effective tax rate in 1999 were not significant. Deferred income taxes were:

---------------------------------------------------------------------------------------------------- In Millions / June 30 2000 2001 ---------------------------------------------------------------------------------------------------- Deferred income tax assets: Revenue items $ 1,320 $ 1,469 Expense items 2,122 1,761 ---------------------------------------------------------------------------------------------------- Deferred income tax assets 3,442 3,230 ---------------------------------------------------------------------------------------------------- Deferred income tax liabilities: Unrealized gain on investments (874) (395) International earnings (1,766) (1,667) Other (121) (55) ---------------------------------------------------------------------------------------------------- Deferred income tax liabilities $(2,761) $(2,117) ====================================================================================================

During fiscal 2001, the U.S. Tax Court issued an adverse ruling which is being appealed to the 9th Circuit Court of Appeals for taxes assessed in 1990 and 1991. Income taxes, except for 1990 and 1991 assessments, have been settled with the Internal Revenue Service (IRS) for all years through 1994. The IRS is examining the Company's 36 1995 and 1996 U.S. income tax returns. Management believes any adjustments which may be required will not be material to the financial statements. Income taxes paid were $874 million in 1999, $800 million in 2000, and $1.3 billion in 2001. Convertible Preferred Stock During 1996, Microsoft issued 12.5 million shares of 2.75% convertible exchangeable principal-protected preferred stock. The Company's convertible preferred stock matured on December 15, 1999. Each preferred share was converted into 1.1273 common shares. Common Stock Shares of common stock outstanding were as follows: In Millions / Year Ended June 30 1999 2000 2001 ------------------------------------------------------------------- Balance, beginning of year 4,940 5,109 5,283 Issued 213 229 189 Repurchased (44) (55) (89) ------------------------------------------------------------------- Balance, end of year 5,109 5,283 5,383 =================================================================== Repurchase Program The Company repurchases its common shares in the open market to provide shares for issuance to employees under stock option and stock purchase plans. During 1998, the Company executed two forward settlement structured repurchase agreements with an independent third party totaling 42 million shares of stock and paid cash for a portion of the purchase price. In 1999, the Company settled the agreements by returning 28 million shares of stock, based upon the stock price on the date of settlement. The timing and method of settlement were at the discretion of the Company. The differential between the cash paid and the price of Microsoft common stock on the date of the agreement was originally reflected in common stock and paid-in capital. In 2001, the Company entered into a structured stock repurchase transaction giving it the right to acquire 5.1 million of its shares (2.55 million shares in October 2001 and 2.55 million shares in June 2002) in exchange for an up-front net payment of $264 million. Put Warrants To enhance its stock repurchase program, Microsoft sold put warrants to independent third parties. These put warrants entitled the holders to sell shares of Microsoft common stock to the Company on certain dates at specified prices. In the third quarter of fiscal 2001, the Company issued 2.8 million shares to settle a portion of the outstanding put warrants. During fiscal 2001, all the remaining outstanding put warrants were either retired or exercised. 37 Other Comprehensive Income The changes in the components of other comprehensive income were as follows:

In Millions / Year Ended June 30 1999 2000 2001 ----------------------------------------------------------------------------------------------------------------------------- Cumulative effect of accounting change, net of tax effect of $(37) $ -- $ -- $ (75) ----------------------------------------------------------------------------------------------------------------------------- Net gain on derivative instruments: Unrealized gains, net of tax effect of $246 -- -- 499 Reclassification adjustment for losses included in net income, net of tax effect of $67 -- -- 135 ----------------------------------------------------------------------------------------------------------------------------- Net gain on derivative instruments -- -- 634 ----------------------------------------------------------------------------------------------------------------------------- Net unrealized investment gains/(losses): Unrealized holding gains/(losses), net of tax effect of $772 in 1999, $248 in 2000, and $(351) in 2001 1,432 531 (1,200) Reclassification adjustment for gains included in net income, net of tax effect of $(205) in 1999, $(420) in 2000, and $(128) in 2001 (380) (814) (260) ----------------------------------------------------------------------------------------------------------------------------- Net unrealized investment gains/(losses) 1,052 (283) (1,460) ----------------------------------------------------------------------------------------------------------------------------- Translation adjustments and other 69 23 (39) ----------------------------------------------------------------------------------------------------------------------------- Other comprehensive income/(loss) $1,121 $(260) $ (940) =============================================================================================================================

The components of accumulated other comprehensive were:

In Millions / June 30 2000 2001 ---------------------------------------------------------------------------------------------------------- Net gains on derivative instruments $ -- $ 177 Net unrealized investment gains 1,676 598 Translation adjustments and other (149) (188) ---------------------------------------------------------------------------------------------------------- Accumulated other comprehensive income $1,527 $ 587 ==========================================================================================================

Employee Stock and Savings Plans Employee Stock Purchase Plan The Company has an employee stock purchase plan for all eligible employees. Under the plan, shares of the Company's common stock may be purchased at six- month intervals at 85% of the lower of the fair market value on the first or the last day of each six-month period. Employees may purchase shares having a value not exceeding 10% of their gross compensation during an offering period. During 1999, 2000, and 2001, employees purchased 2.7 million, 2.5 million, and 5.7 million shares at average prices of $52.59, $72.38, and $36.87 per share. At June 30, 2001, 62.7 million shares were reserved for future issuance. Savings Plan The Company has a savings plan, which qualifies under Section 401(k) of the Internal Revenue Code. Participating employees may contribute up to 15% of their pretax salary, but not more than statutory limits. The Company contributes fifty cents for each dollar a participant contributes, with a maximum contribution of 3% of a participant's earnings. Matching contributions were $49 million, $65 million, and $86 million in 1999, 2000, and 2001. Stock Option Plans The Company has stock option plans for directors, officers, and employees, which provide for nonqualified and incentive stock options. Options granted prior to 1995 generally vest over four and one-half years and expire 10 years from the date of grant. Options granted between 1995 and 2000 generally vest over four and one-half years and expire seven years from the date of grant, while certain options vest either over four and one-half years or over seven and one-half years and expire after 10 years. Options granted during 2001vest over four and one-half years and expire 10 years from the date of grant. At June 30, 2001, options for 331 million shares were vested and 550 million shares were available for future grants under the plans. 38 Stock options outstanding were as follows: In Millions, Except Per Share Amounts Price per Share ------------------------------ Weighted Shares Range Average ------------------------------------------------------------------------- Balance, June 30, 1998 893 $ 0.56 - $ 43.63 $11.94 Granted 78 45.59 - 83.28 54.62 Exercised (175) 0.56 - 53.63 6.29 Canceled (30) 4.25 - 74.28 21.06 ---- Balance, June 30, 1999 766 0.56 - 83.28 23.87 Granted 304 65.56 - 119.13 79.87 Exercised (198) 0.56 - 82.94 9.54 Canceled (40) 4.63 - 116.56 36.50 ---- Balance, June 30, 2000 832 0.56 - 119.13 41.23 Granted 224 41.50 - 80.00 60.84 Exercised (123) 0.59 - 85.81 11.13 Canceled (35) 13.83 - 119.13 63.57 ---- Balance, June 30, 2001 898 0.56 - 119.13 49.54 ========================================================================= For various price ranges, weighted average characteristics of outstanding stock options at June 30, 2001 were as follows: In Millions, Except Per Share Amounts

Outstanding Options Exercisable Options ------------------------------------------------------------------------------ Range of Remaining Weighted Weighted Exercise Prices Shares Life (Years) Average Price Shares Average Price ---------------------------------------------------------------------------------------------- $0.56- $5.97 73 1.6 $ 4.75 67 $ 4.71 5.98- 13.62 75 1.3 11.01 72 11.02 13.63- 29.80 110 3.0 15.06 92 14.92 29.81- 43.62 84 3.6 32.20 52 32.08 43.63- 60.00 191 7.8 55.82 25 53.17 60.01- 83.28 210 6.1 68.28 11 69.20 83.29- 119.13 155 5.5 89.91 12 87.39 ==============================================================================================

39 The Company follows Accounting Principles Board Opinion 25, Accounting for Stock Issued to Employees, to account for stock option and employee stock purchase plans. An alternative method of accounting for stock options is SFAS 123, Accounting for Stock-Based Compensation. Under SFAS 123, employee stock options are valued at grant date using the Black-Scholes valuation model, and this compensation cost is recognized ratably over the vesting period. Had compensation cost for the Company's stock option and employee stock purchase plans been determined as prescribed by SFAS 123, pro forma income statements for 1999, 2000, and 2001 would have been as follows: In Millions, Except Per Share Amounts

Year Ended June 30 1999 2000 2001 ------------------------------------------------------------------------------------------------------------------ Reported Pro Forma Reported Pro Forma Reported Pro Forma -------------------------------------------------------------------- Revenue $19,747 $19,747 $22,956 $22,956 $25,296 $25,296 Operating expenses: Cost of revenue 2,814 3,013 3,002 3,277 3,455 3,775 Research and development 2,970 3,479 3,772 4,814 4,379 6,106 Sales and marketing 3,238 3,445 4,126 4,468 4,885 5,888 General and administrative 715 841 1,050 1,284 857 1,184 ------------------------------------------------------------------------------------------------------------------ Total operating expenses 9,737 10,778 11,950 13,843 13,576 16,953 ------------------------------------------------------------------------------------------------------------------ Operating income 10,010 8,969 11,006 9,113 11,720 8,343 Losses on equity investees and other (70) (70) (57) (57) (159) (159) Investment income/(loss) 1,951 1,951 3,326 3,326 (36) (36) ------------------------------------------------------------------------------------------------------------------ Income before income taxes 11,891 10,850 14,275 12,382 11,525 8,148 Provision for income taxes 4,106 3,741 4,854 4,210 3,804 2,689 ------------------------------------------------------------------------------------------------------------------ Income before accounting change 7,785 7,109 9,421 8,172 7,721 5,459 Cumulative effect of accounting change -- -- -- -- (375) (375) ================================================================================================================== Net income $ 7,785 $ 7,109 $ 9,421 $ 8,172 $ 7,346 $ 5,084 ================================================================================================================== Basic earnings per share $ 1.54 $ 1.41 $ 1.81 $ 1.57 $ 1.38 $ 0.95 ================================================================================================================== Diluted earnings per share $ 1.42 $ 1.30 $ 1.70 $ 1.48 $ 1.32 $ 0.91 ==================================================================================================================

The weighted average Black-Scholes value of options granted under the stock option plans during 1999, 2000, and 2001 was $20.90, $36.67, and $29.31. Value was estimated using a weighted average expected life of 5.0 years in 1999, 6.2 years in 2000, and 6.4 years in 2001, no dividends, volatility of .32 in 1999, .33 in 2000, and .39 in 2001, and risk-free interest rates of 4.9%, 6.2%, and 5.3% in 1999, 2000, and 2001. 40 Earnings Per Share Basic earnings per share is computed on the basis of the weighted average number of common shares outstanding. Diluted earnings per share is computed on the basis of the weighted average number of common shares outstanding plus the effect of outstanding preferred shares using the "if-converted" method, assumed net-share settlement of common stock structured repurchases, outstanding put warrants using the "reverse treasury stock" method, and outstanding stock options using the "treasury stock" method. The components of basic and diluted earnings per share were as follows:

In Millions, Except Per Share Amounts ------------------------------------------------------------------------------------------ Year Ended June 30 1999 2000 2001 ------------------------------------------------------------------------------------------ Income before accounting change $7,785 $9,421 $7,721 Preferred stock dividends 28 13 -- ------------------------------------------------------------------------------------------ Net income available for common shareholders $7,757 $9,408 $7,721 ========================================================================================== Weighted average outstanding shares of common stock 5,028 5,189 5,341 Dilutive effect of: Common stock under structured repurchases 13 -- -- Put warrants -- 2 21 Preferred stock 16 7 -- Employee stock options 425 338 212 ------------------------------------------------------------------------------------------ Common stock and common stock equivalents 5,482 5,536 5,574 ========================================================================================== Earnings per share before accounting change: Basic $ 1.54 $ 1.81 $ 1.45 ========================================================================================== Diluted $ 1.42 $ 1.70 $ 1.38 ==========================================================================================

Operational Transactions In November 1998, Microsoft acquired LinkExchange, Inc., a leading provider of online marketing services to Web site owners and small- and medium-sized businesses. Microsoft paid $265 million in stock. In November 1999, Expedia, Inc. completed an initial public offering of its common stock. Expedia, which is majority-owned by Microsoft, is a leading provider of branded online travel services for leisure and small business travelers. Expedia's financial results and financial condition are consolidated with the operations of Microsoft. In January 2000, the Company merged with Visio Corporation in a transaction that was accounted for as a pooling of interests. Microsoft issued 14 million shares in the exchange for the outstanding stock of Visio. Visio's assets and liabilities, which were nominal, are included with those of Microsoft as of the merger. Operating results for Visio from periods prior to the merger were not material to the combined results of the two companies. Accordingly, the financial statements for such periods have not been restated. In July 2000, the Company acquired an interest in Telewest Communications plc for approximately $2.6 billion in stock. Telewest is a leading broadband cable communications operator in the United Kingdom. In April 2001, the Company acquired Great Plains Software, Inc. for approximately $1.1 billion in stock. Great Plains is a leading supplier of mid- market business applications. The acquisition was accounted for by the purchase method and operating results for Great Plains subsequent to the date of acquisition are included with those of Microsoft. The pro forma impact of Great Plains' operating results prior to the date of acquisition was not material. Commitments The Company has operating leases for most U.S. and international sales and support offices and certain equipment. Rental expense for operating leases was $135 million, $201 million, and $281 million in 1999, 2000, and 2001. Future minimum rental commitments under noncancellable leases, in millions of dollars, are: 2002, $218; 2003, $210; 2004, $185; 2005, $162; 2006, $140; and thereafter, $430. Microsoft has committed $181 million for constructing new buildings and $46 million for the manufacturing of products. In addition, the Company has guaranteed $420 million in debt of its equity investees. 41 Contingencies On January 23, 2001, Microsoft and Sun Microsystems, Inc. ("Sun") entered into a Settlement Agreement. Under the terms of the public agreement, the parties agreed to a dismissal with prejudice of all pending claims in the suit brought by Sun against Microsoft on October 7, 1997 in the U.S. District Court for the Northern District of California. Sun also granted to Microsoft a non-exclusive license to continue distribution of certain Sun technology for a seven year period. Microsoft further agreed to pay Sun $20 million. The Company is a defendant in U.S. v. Microsoft, a lawsuit filed by the Antitrust Division of the U.S. Department of Justice (DOJ) and a group of eighteen state Attorneys General alleging violations of the Sherman Act and various state antitrust laws. After the trial, the District Court entered Findings of Fact and Conclusions of Law stating that Microsoft had violated Sections 1 and 2 of the Sherman Act and various state antitrust laws. A Judgment was entered on June 7, 2000 ordering, among other things, the breakup of Microsoft into two companies. The Judgment was stayed pending an appeal. On June 28, 2001, the U.S. Court of Appeals for the District of Columbia Circuit affirmed in part, reversed in part, and vacated the Judgment in its entirety and remanded the case to the District Court for a new trial on one Section 1 claim and for entry of a new judgment consistent with its ruling. In its ruling, the Court of Appeals substantially narrowed the bases of liability found by the District Court, but affirmed some of the District Court's conclusions that Microsoft had violated Section 2. On September 6, 2001, the plaintiffs announced that on remand they will not ask the Court to break Microsoft up, that they will seek imposition of conduct remedies, and that they will not retry the one Section 1 claim returned to the District Court by the Court of Appeals. On August 7, 2001, Microsoft petitioned the Supreme Court for a writ of certiorari to review the appellate court's ruling concerning its disqualification of the District Court judge. Microsoft may petition the Supreme Court to review other aspects of the appellate court's decision after final judgment is entered. In other ongoing investigations, the DOJ and several state Attorneys General have requested information from Microsoft concerning various issues. In addition, the European Commission has instituted proceedings in which it alleges that Microsoft has failed to disclose information that Microsoft competitors claim they need to interoperate fully with Windows 2000 clients and servers and has engaged in discriminatory licensing of such technology. The remedies sought, though not fully defined, include mandatory disclosure of Microsoft Windows operating system technology and imposition of fines. Microsoft denies the European Commission's allegations and intends to contest the proceedings vigorously. A large number of overcharge class action lawsuits have been initiated against Microsoft. These cases allege that Microsoft has competed unfairly and unlawfully monopolized alleged markets for operating systems and certain software applications and seek to recover alleged overcharges that the complaints contend Microsoft charged for these products. Microsoft believes the claims are without merit and is vigorously defending the cases. To date, Microsoft has won dismissals of all claims for damages by indirect purchasers under Federal law and in 15 separate state court proceedings. Claims on behalf of foreign purchasers have also been dismissed. Plaintiffs have appealed most of these rulings. While no trials or other proceedings have been held concerning any liability issues, courts in several states have ruled that these cases may proceed as class actions, while one court has denied class certification status to the claims in that state proceeding. Two purported class action employment discrimination cases are pending against Microsoft, Donaldson v. Microsoft, a class case consolidating three separately filed class action complaints filed in October 2000 and February 2001 in Federal court in Seattle, Washington, and Jackson v. Microsoft, an amendment to an existing case alleging class claims filed on January 3, 2001 in Federal court in Washington, D.C. Microsoft's motion to transfer the Jackson case to Federal court in Seattle was granted on May 3, 2001. The Donaldson plaintiffs purport to represent a nationwide class of current and former African American and female Microsoft employees and seek injunctive relief, an unspecified amount of compensatory and punitive damages, and attorneys' fees. The Jackson plaintiffs purport to represent a nationwide class of current and former African American Microsoft employees and seeks injunctive relief, $5 billion in compensatory and punitive damages, and attorneys' fees. Both cases allege that Microsoft's compensation, evaluation, and promotion policies are discriminatory with respect to the plaintiffs in violation of Title VII of the 1964 Civil Rights Act and 42 U.S.C. (S) 1981. Microsoft denies the allegations and is vigorously defending both cases. 42 The Securities and Exchange Commission is conducting a non-public investigation into the Company's accounting reserve practices. Microsoft is also subject to various legal proceedings and claims that arise in the ordinary course of business. Management currently believes that resolving these matters will not have a material adverse impact on the Company's financial position or its results of operations. Segment Information In Millions / Year Ended June 30

Desktop and Consumer Enterprise Software, Software and Services, and Consumer Commerce Reconciling Services Devices Investments Other Amounts Consolidated ------------------------------------------------------------------------------------------------------------------------------ 1999 Revenue $17,810 $ 1,148 $ 62 $593 $ 134 $19,747 ============================================================================================================================== 2000 Revenue $20,410 $ 1,654 $ 182 $691 $ 19 $22,956 Operating income/(loss) 13,210 (1,090) (60) 86 (1,140) 11,006 ============================================================================================================================== 2001 Revenue $22,720 $ 1,961 $ 522 $652 $ (559) $25,296 Operating income/(loss) 14,261 (1,666) (222) 97 (750) 11,720 ==============================================================================================================================

Desktop and Enterprise Software and Services Revenue:

In Millions / Year Ended June 30 1999 2000 2001 -------------------------------------------------------------------------------------------------------- Desktop Applications $ 7,590 $ 9,013 $ 9,580 Desktop Platforms 6,932 7,383 8,265 -------------------------------------------------------------------------------------------------------- Desktop Software 14,522 16,396 17,845 Enterprise Software and Services 3,288 4,014 4,875 -------------------------------------------------------------------------------------------------------- Total Desktop and Enterprise Software and Services $17,810 $20,410 $22,720 ========================================================================================================

In 2001, Microsoft changed the composition of its segments to reflect the internal reorganization around Microsoft .NET, the Company's vision for the next-generation of Internet-based products and services. Except for 1999 operating income/(loss), prior year disclosures have been restated for consistent presentation. It is not practicable to discern operating income for 1999 for the current segments due to previous internal reorganizations. Microsoft has four segments: Desktop and Enterprise Software and Services; Consumer Software, Services, and Devices; Consumer Commerce Investments; and Other. Desktop and Enterprise Software and Services operating segment includes Desktop Applications, Desktop Platforms, and Enterprise Software and Services. Desktop Applications include Microsoft Office; Project; Visio; client access licenses for Windows 2000 Server, Windows NT Server, Exchange, and BackOffice; Microsoft Great Plains; and bCentral. Desktop Platforms include Windows 2000 Professional, Windows NT Workstation, Windows Millennium Edition (Windows Me), Windows 98, and other desktop operating systems. Enterprise Software and Services includes Windows NT Server and Windows 2000 Server operating systems, SQL Server and client access licenses, Exchange Server, developer tools, consulting services, product support services, and training and certification. Consumer Software, Services, and Devices operating segment includes MSN Internet access, MSN network services, WebTV Internet access and services, gaming, learning and productivity software, mobile and wireless devices, and embedded systems. Consumer Commerce Investments operating segment includes Expedia, Inc., the HomeAdvisor online real estate service, and the CarPoint online automotive service. Other includes Hardware and Press. Segment information is presented in accordance with SFAS 131, Disclosures about Segments of an Enterprise and Related Information. This standard is based on a management approach, which requires segmentation based upon the Company's internal organization and disclosure of revenue and operating income based upon internal accounting methods. The Company's financial reporting systems present various data for management to run the business, including internal profit and loss statements (P&Ls) prepared on a basis not consistent with generally accepted accounting principles. Assets are not allocated to segments for internal reporting purposes. 43 Reconciling items for revenue include certain elements of unearned revenue and the treatment of certain channel inventory amounts and estimates. In addition to the reconciling items for revenue, reconciling items for operating income/(loss) include general and administrative expenses ($1,050 million in 2000 and $857 million in 2001), certain research expenses ($141 million in 2000 and $154 million in 2001), and other corporate level adjustments. The internal P&Ls use accelerated methods of depreciation and amortization. Additionally, losses on equity investees and minority interest are classified in operating income for internal reporting presentations. Revenue attributable to U.S. operations includes shipments to customers in the United States, licensing to OEMs and certain multinational organizations, and exports of finished goods, primarily to Asia, Latin America, and Canada. Revenue from U.S. operations totaled $13.7 billion, $15.7 billion, and $17.8 billion in 1999, 2000, and 2001. Revenue from outside the United States, excluding licensing to OEMs and certain multinational organizations and U.S. exports, totaled $6.0 billion, $7.3 billion, and $7.5 billion in 1999, 2000, and 2001. A single customer accounted for approximately 11%, 9%, and 8% of revenue in 1999, 2000, and 2001. Long-lived assets totaled $1.8 billion and $2.2 billion in the United States in 2000 and 2001 and $126 million and $154 million in other countries in 2000 and 2001. Subsequent Event On July 16, 2001, USA Networks, Inc. (USA) announced an agreement to acquire a controlling interest in Expedia, Inc. through the purchase of up to 37.5 million shares, approximately 75% of the current outstanding shares. If holders of more than 37.5 million Expedia shares elect to sell their shares to USA, there will be a pro rata reduction among all of those electing shareholders. Microsoft has agreed to transfer all of its 33.7 million shares and warrants, subject to pro- ration. It is expected that the transaction will close by December 31, 2001. 44 Quarterly Information (In millions, except per share amounts) (Unaudited)

Quarter Ended --------------------------------------------------------------------------------------------------------- Sept. 30 Dec. 31 Mar. 31 June 30 Year --------------------------------------------------------------------------------------------------------- 1999 Revenue $4,193 $5,195 $4,595 $5,764 $19,747 Gross profit 3,544 4,407 3,887 5,095 16,933 Net income 1,683 1,983 1,917 2,202 7,785 Basic earnings per share 0.34 0.40 0.38 0.43 1.54 Diluted earnings per share 0.31 0.36 0.35 0.40 1.42 ------------------------------------------------------------------------------------------------------ 2000 Revenue $5,384 $6,112 $5,656 $5,804 $22,956 Gross profit 4,672 5,356 4,904 5,022 19,954 Net income 2,191 2,436 2,385 2,409 9,421 Basic earnings per share 0.43 0.47 0.46 0.46 1.81 Diluted earnings per share 0.40 0.44 0.43 0.44 1.70 ------------------------------------------------------------------------------------------------------ 2001 Revenue (1) $5,766 $6,550 $6,403 $6,577 $25,296 Gross profit 4,941 5,686 5,504 5,710 21,841 Net income (2)(3) 2,206 2,624 2,451 65 7,346 Basic earnings per share (2)(3) 0.42 0.49 0.46 0.01 1.38 Diluted earnings per share (2)(3) 0.40 0.47 0.44 0.01 1.32 ---------------------------------------------------------------------------------------------------------

(1) For the first three quarters of 2001, revenue and cost of revenue have been reclassified to report Expedia merchant revenue on a net basis, which represents the amount charged to the customer less the amount paid to the supplier. (2) First quarter of 2001 includes an unfavorable cumulative effect of accounting change of $375 million or $0.07 per basic share and $0.06 per diluted share. (3) Fourth quarter of 2001 includes $3.92 billion (pre-tax) in impairments of certain investments, primarily cable and telecommunication investments. 45 Independent Auditors' Report -------------------------------------------------------------------------------- To the Board of Directors and Stockholders of Microsoft Corporation: We have audited the accompanying consolidated balance sheets of Microsoft Corporation and subsidiaries as of June 30, 2000 and 2001, and the related consolidated statements of income, cash flows, and stockholders' equity for each of the three years in the period ended June 30, 2001. These financial statements are the responsibility of the Company's management. Our responsibility is to express an opinion on these financial statements based on our audits. We conducted our audits in accordance with auditing standards generally accepted in the United States of America. Those standards require that we plan and perform the audit to obtain reasonable assurance about whether the financial statements are free of material misstatement. An audit includes examining, on a test basis, evidence supporting the amounts and disclosures in the financial statements. An audit also includes assessing the accounting principles used and significant estimates made by management, as well as evaluating the overall financial statement presentation. We believe that our audits provide a reasonable basis for our opinion. In our opinion, such consolidated financial statements present fairly, in all material respects, the financial position of Microsoft Corporation and subsidiaries as of June 30, 2000 and 2001, and the results of their operations and their cash flows for each of the three years in the period ended June 30, 2001 in conformity with accounting principles generally accepted in the United States of America. As discussed in the notes to the financial statements, the Company was required to adopt Statement of Financial Accounting Standards No. 133, Accounting for Derivative Instruments and Hedging Activities, effective July 1, 2000. Deloitte & Touche LLP Seattle, Washington July 19, 2001 (September 6, 2001 as to the second paragraph of Contingencies note) 46 Item 9. Changes in and Disagreements with Accountants on Accounting and Financial Disclosures None. PART III Item 10. Directors of the Registrant Information with respect to Directors may be found under the caption "Election of Directors and Management Information" of the Company's Proxy Statement dated September 10, 2001, for the Annual Meeting of Shareholders to be held November 7, 2001 (the "Proxy Statement"). Such information is incorporated herein by reference. Item 11. Executive Compensation The information in the Proxy Statement set forth under the captions "Information Regarding Executive Officer Compensation" and "Information Regarding the Board and its Committees" is incorporated herein by reference. Item 12. Security Ownership of Certain Beneficial Owners and Management The information set forth under the caption "Information Regarding Beneficial Ownership of Principal Shareholders, Directors, and Management" of the Proxy Statement is incorporated herein by reference. Item 13. Certain Relationships and Related Transactions The information set forth under the captions "Certain Relationships and Related Transactions" and "Indebtedness of Executive Officers" of the Proxy Statement is incorporated herein by reference. 47 PART IV Item 14. Exhibits, Financial Statement Schedules, and Reports on Form 8-K (a) Financial Statements and Schedules The financial statements are set forth under Item 8 of this report on Form 10-K. Financial statement schedules have been omitted since they are either not required, not applicable, or the information is otherwise included. (b) Reports on Form 8-K The Company filed no reports on Form 8-K during the quarter ended June 30, 2001. (c) Exhibit Listing Exhibit Number Description -------------- ----------- 3.1 Restated Articles of Incorporation of Microsoft Corporation (1) 3.2 Bylaws of Microsoft Corporation 10.1 Microsoft Corporation 1991 Stock Option Plan (2) 10.2 Microsoft Corporation 1981 Stock Option Plan (3) 10.3 Microsoft Corporation 1999 Stock Option Plan for Non- Employee Directors (4) 10.4 Microsoft Corporation Stock Option Plan for Consultants and Advisors (5) 10.5 Microsoft Corporation 1997 Employee Stock Purchase Plan 10.6 Microsoft Corporation Savings Plus Plan (6) 10.7 Trust Agreement dated June 1, 1993 between Microsoft Corporation and First Interstate Bank of Washington (7) 10.8 Form of Indemnification Agreement (7) 21. Subsidiaries of Registrant 23. Independent Auditors' Consent _____________________________ (1) Incorporated by reference to Annual Report on Form 10-K For The Fiscal Year Ended June 30, 1999. (2) Incorporated by reference to Annual Report on Form 10-K For The Fiscal Year Ended June 30, 1997. (3) Incorporated by reference to Registration Statement 33-37623 on Form S-8. (4) Incorporated by reference to Registration Statement 333-91755 on Form S-8. (5) Incorporated by reference to Annual Report on Form 10-K For The Fiscal Year Ended June 30, 1994. (6) Incorporated by reference to Annual Report on Form 10-K For The Fiscal Year Ended June 30, 2000. (7) Incorporated by reference to Annual Report on Form 10-K For The Fiscal Year Ended June 30, 1993. 48 Signatures Pursuant to the requirements of Section 13 of 15(d) of the Securities Exchange Act of 1934, the Registrant has duly caused this report to be signed on its behalf by the undersigned; thereunto duly authorized, in the City of Redmond, State of Washington, on September 17, 2001. MICROSOFT CORPORATION By /s/ John G. Connors ------------------------------------------- John G. Connors Senior Vice President; Chief Financial Officer Pursuant to the requirements of the Securities Exchange Act of 1934, this report has been signed below by the following persons on behalf of Registrant and in the capacities indicated on September 17, 2001.

Signature Title /s/ William H. Gates, III -------------------------------------- Chairman of the Board of Directors William H. Gates, III and Chief Software Architect /s/ Steven A. Ballmer -------------------------------------- Steven A. Ballmar Chief Executive Officer /s/ James I. Cash, Jr. -------------------------------------- James I. Cash, Jr. Director /s/ Raymond V. Gilmartin -------------------------------------- Raymond V. Gilmartin Director /s/ Ann McLaughlin Korologos -------------------------------------- Ann McLaughlin Korologos Director /s/ David F. Marquardt -------------------------------------- David F. Marquardt Director /s/ Wm. G. Reed, Jr. -------------------------------------- Wm. G. Reed, Jr. Director /s/ Jon A. Shirley -------------------------------------- Jon A. Shirley Director /s/ John G. Connors -------------------------------------- John G. Connors Senior Vice President; Chief Financial Officer (Principal Financial and Accounting Officer)

49